@@ -44,7 +44,7 @@ static LONG dll_count;
  * ATLRegistrar implementation
  */
 
-static struct {
+static const struct {
     WCHAR name[22];
     HKEY  key;
 } root_keys[] = {
