@@ -200,6 +200,9 @@ struct IDirect3DVolume8Impl
     /* IDirect3DVolume8 fields */
     IWineD3DVolume             *wineD3DVolume;
 
+    /* The volume container */
+    IUnknown                    *container;
+
     /* If set forward refcounting to this object */
     IUnknown                    *forwardReference;
 };
@@ -253,6 +256,9 @@ struct IDirect3DSurface8Impl
     /* Parent reference */
     LPDIRECT3DDEVICE8                  parentDevice;
 
+    /* The surface container */
+    IUnknown                    *container;
+
     /* If set forward refcounting to this object */
     IUnknown                    *forwardReference;
 
@@ -603,6 +609,8 @@ extern HRESULT WINAPI D3D8CB_CreateRenderTarget(IUnknown *device, IUnknown *pSup
                                          DWORD MultisampleQuality, BOOL Lockable,
                                          IWineD3DSurface** ppSurface, HANDLE* pSharedHandle);
 
+extern ULONG WINAPI D3D8CB_DestroySwapChain (IWineD3DSwapChain *pSwapChain);
+
 extern ULONG WINAPI D3D8CB_DestroyDepthStencilSurface (IWineD3DSurface *pSurface);
 
 extern ULONG WINAPI D3D8CB_DestroyRenderTarget (IWineD3DSurface *pSurface);
