@@ -62,6 +62,14 @@ IDirectDraw2Impl_QueryInterface(LPDIRECTDRAW2 This, REFIID iid, LPVOID *ppObj)
 				       iid, ppObj);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_QueryInterface(LPDIRECTDRAW3 This, REFIID iid, LPVOID *ppObj)
+{
+    return IDirectDraw7_QueryInterface(COM_INTERFACE_CAST(IDirectDrawImpl,
+							  IDirectDraw3,
+							  IDirectDraw7, This),
+				       iid, ppObj);
+}
 
 static HRESULT WINAPI
 IDirectDraw4Impl_QueryInterface(LPDIRECTDRAW4 This, REFIID iid, LPVOID *ppObj)
@@ -98,6 +106,19 @@ IDirectDraw2Impl_AddRef(LPDIRECTDRAW2 iface)
     return ref;
 }
 
+static ULONG WINAPI
+IDirectDraw3Impl_AddRef(LPDIRECTDRAW3 iface)
+{
+    ICOM_THIS_FROM(IDirectDrawImpl, IDirectDraw3, iface);
+    ULONG ref = InterlockedIncrement(&This->ref3);
+
+    TRACE("(%p) : incrementing IDirectDraw3 refcount from %u.\n", This, ref -1);
+
+    if(ref == 1) InterlockedIncrement(&This->numIfaces);
+
+    return ref;
+}
+
 static ULONG WINAPI
 IDirectDraw4Impl_AddRef(LPDIRECTDRAW4 iface)
 {
@@ -145,6 +166,23 @@ IDirectDraw2Impl_Release(LPDIRECTDRAW2 iface)
     return ref;
 }
 
+static ULONG WINAPI
+IDirectDraw3Impl_Release(LPDIRECTDRAW3 iface)
+{
+    ICOM_THIS_FROM(IDirectDrawImpl, IDirectDraw3, iface);
+    ULONG ref = InterlockedDecrement(&This->ref3);
+
+    TRACE_(ddraw)("(%p)->() decrementing IDirectDraw3 refcount from %u.\n", This, ref +1);
+
+    if(ref == 0)
+    {
+        ULONG ifacecount = InterlockedDecrement(&This->numIfaces);
+        if(ifacecount == 0) IDirectDrawImpl_Destroy(This);
+    }
+
+    return ref;
+}
+
 static ULONG WINAPI
 IDirectDraw4Impl_Release(LPDIRECTDRAW4 iface)
 {
@@ -178,6 +216,14 @@ IDirectDraw2Impl_Compact(LPDIRECTDRAW2 This)
 						   This));
 }
 
+    static HRESULT WINAPI
+IDirectDraw3Impl_Compact(LPDIRECTDRAW3 This)
+{
+    return IDirectDraw7_Compact(COM_INTERFACE_CAST(IDirectDrawImpl,
+						   IDirectDraw3, IDirectDraw7,
+						   This));
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_Compact(LPDIRECTDRAW4 This)
 {
@@ -210,6 +256,18 @@ IDirectDraw2Impl_CreateClipper(LPDIRECTDRAW2 This, DWORD dwFlags,
 				      dwFlags, ppClipper, pUnkOuter);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_CreateClipper(LPDIRECTDRAW3 This, DWORD dwFlags,
+			       LPDIRECTDRAWCLIPPER *ppClipper,
+			       IUnknown *pUnkOuter)
+{
+    return IDirectDraw7_CreateClipper(COM_INTERFACE_CAST(IDirectDrawImpl,
+							 IDirectDraw3,
+							 IDirectDraw7,
+							 This),
+				      dwFlags, ppClipper, pUnkOuter);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_CreateClipper(LPDIRECTDRAW4 This, DWORD dwFlags,
 			       LPDIRECTDRAWCLIPPER *ppClipper,
@@ -271,6 +329,31 @@ IDirectDraw2Impl_CreatePalette(LPDIRECTDRAW2 This, DWORD dwFlags,
     return hr;
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_CreatePalette(LPDIRECTDRAW3 This, DWORD dwFlags,
+			       LPPALETTEENTRY pEntries,
+			       LPDIRECTDRAWPALETTE *ppPalette,
+			       IUnknown *pUnkOuter)
+{
+    HRESULT hr;
+    hr = IDirectDraw7_CreatePalette(COM_INTERFACE_CAST(IDirectDrawImpl,
+							 IDirectDraw3,
+							 IDirectDraw7,
+							 This),
+				      dwFlags, pEntries, ppPalette, pUnkOuter);
+    if(SUCCEEDED(hr) && *ppPalette)
+    {
+        IDirectDrawPaletteImpl *impl = ICOM_OBJECT(IDirectDrawPaletteImpl, IDirectDrawPalette, *ppPalette);
+        IDirectDraw7_Release(COM_INTERFACE_CAST(IDirectDrawImpl,
+                             IDirectDraw3,
+                             IDirectDraw7,
+                             This));
+        IDirectDraw4_AddRef(This);
+        impl->ifaceToRelease = (IUnknown *) This;
+    }
+    return hr;
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_CreatePalette(LPDIRECTDRAW4 This, DWORD dwFlags,
 			       LPPALETTEENTRY pEntries,
@@ -370,6 +453,42 @@ IDirectDraw2Impl_CreateSurface(LPDIRECTDRAW2 This, LPDDSURFACEDESC pSDesc,
     return hr;
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_CreateSurface(LPDIRECTDRAW3 This, LPDDSURFACEDESC pSDesc,
+			       LPDIRECTDRAWSURFACE *ppSurface,
+			       IUnknown *pUnkOuter)
+{
+    LPDIRECTDRAWSURFACE7 pSurface7;
+    IDirectDrawSurfaceImpl *impl;
+    HRESULT hr;
+
+    hr = IDirectDraw7_CreateSurface(COM_INTERFACE_CAST(IDirectDrawImpl,
+						       IDirectDraw3,
+						       IDirectDraw7,
+						       This),
+				    (LPDDSURFACEDESC2)pSDesc, &pSurface7, pUnkOuter);
+
+    /* This coercion is safe, since the IDirectDrawSurface3 vtable has the
+     * IDirectDrawSurface vtable layout at the beginning  */
+    *ppSurface = (LPDIRECTDRAWSURFACE)COM_INTERFACE_CAST(IDirectDrawSurfaceImpl,
+				    IDirectDrawSurface7, IDirectDrawSurface3,
+				    pSurface7);
+
+    impl = ICOM_OBJECT(IDirectDrawSurfaceImpl, IDirectDrawSurface7, pSurface7);
+    if(SUCCEEDED(hr) && impl)
+    {
+        impl->version = 3;
+        IDirectDraw7_Release(COM_INTERFACE_CAST(IDirectDrawImpl,
+                             IDirectDraw3,
+                             IDirectDraw7,
+                             This));
+        IDirectDraw3_AddRef(This);
+        impl->ifaceToRelease = (IUnknown *) This;
+    }
+
+    return hr;
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_CreateSurface(LPDIRECTDRAW4 This, LPDDSURFACEDESC2 pSDesc,
 			       LPDIRECTDRAWSURFACE4 *ppSurface,
@@ -447,6 +566,30 @@ IDirectDraw2Impl_DuplicateSurface(LPDIRECTDRAW2 This, LPDIRECTDRAWSURFACE pSrc,
     return hr;
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_DuplicateSurface(LPDIRECTDRAW3 This, LPDIRECTDRAWSURFACE pSrc,
+				  LPDIRECTDRAWSURFACE *ppDst)
+{
+    LPDIRECTDRAWSURFACE7 pDst7;
+    HRESULT hr;
+
+    hr = IDirectDraw7_DuplicateSurface(COM_INTERFACE_CAST(IDirectDrawImpl,
+							  IDirectDraw3,
+							  IDirectDraw7, This),
+				       COM_INTERFACE_CAST(IDirectDrawSurfaceImpl,
+							  IDirectDrawSurface3,
+							  IDirectDrawSurface7,
+							  pSrc),
+				       &pDst7);
+
+    /* This coercion is safe, since the IDirectDrawSurface3 vtable has the
+     * IDirectDrawSurface vtable layout at the beginning  */
+    *ppDst = (LPDIRECTDRAWSURFACE)COM_INTERFACE_CAST(IDirectDrawSurfaceImpl, IDirectDrawSurface7,
+				IDirectDrawSurface3, pDst7);
+
+    return hr;
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_DuplicateSurface(LPDIRECTDRAW4 This,
 				  LPDIRECTDRAWSURFACE4 pSrc,
@@ -514,6 +657,24 @@ IDirectDraw2Impl_EnumDisplayModes(LPDIRECTDRAW2 This, DWORD dwFlags,
 					 EnumDisplayModesCallbackThunk);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_EnumDisplayModes(LPDIRECTDRAW3 This, DWORD dwFlags,
+				  LPDDSURFACEDESC pDDSD, LPVOID context,
+				  LPDDENUMMODESCALLBACK cb)
+{
+    struct displaymodescallback_context cbcontext;
+
+    cbcontext.func    = cb;
+    cbcontext.context = context;
+
+    return IDirectDraw7_EnumDisplayModes(COM_INTERFACE_CAST(IDirectDrawImpl,
+							    IDirectDraw3,
+							    IDirectDraw7,
+							    This),
+					 dwFlags, (LPDDSURFACEDESC2)pDDSD, &cbcontext,
+					 EnumDisplayModesCallbackThunk);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_EnumDisplayModes(LPDIRECTDRAW4 This, DWORD dwFlags,
 				  LPDDSURFACEDESC2 pDDSD, LPVOID context,
@@ -581,6 +742,23 @@ IDirectDraw2Impl_EnumSurfaces(LPDIRECTDRAW2 This, DWORD dwFlags,
 				     &cbcontext, EnumSurfacesCallbackThunk);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_EnumSurfaces(LPDIRECTDRAW3 This, DWORD dwFlags,
+			      LPDDSURFACEDESC pDDSD, LPVOID context,
+			      LPDDENUMSURFACESCALLBACK cb)
+{
+    struct surfacescallback_context cbcontext;
+
+    cbcontext.func    = cb;
+    cbcontext.context = context;
+
+    return IDirectDraw7_EnumSurfaces(COM_INTERFACE_CAST(IDirectDrawImpl,
+							IDirectDraw3,
+							IDirectDraw7, This),
+				     dwFlags, (LPDDSURFACEDESC2)pDDSD,
+				     &cbcontext, EnumSurfacesCallbackThunk);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_EnumSurfaces(LPDIRECTDRAW4 This, DWORD dwFlags,
 			      LPDDSURFACEDESC2 pDDSD, LPVOID context,
@@ -611,6 +789,15 @@ IDirectDraw2Impl_FlipToGDISurface(LPDIRECTDRAW2 This)
 							    This));
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_FlipToGDISurface(LPDIRECTDRAW3 This)
+{
+    return IDirectDraw7_FlipToGDISurface(COM_INTERFACE_CAST(IDirectDrawImpl,
+							    IDirectDraw3,
+							    IDirectDraw7,
+							    This));
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_FlipToGDISurface(LPDIRECTDRAW4 This)
 {
@@ -636,6 +823,14 @@ IDirectDraw2Impl_GetCaps(LPDIRECTDRAW2 This, LPDDCAPS pDDC1, LPDDCAPS pDDC2)
 						   This), pDDC1, pDDC2);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_GetCaps(LPDIRECTDRAW3 This, LPDDCAPS pDDC1, LPDDCAPS pDDC2)
+{
+    return IDirectDraw7_GetCaps(COM_INTERFACE_CAST(IDirectDrawImpl,
+						   IDirectDraw3, IDirectDraw7,
+						   This), pDDC1, pDDC2);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_GetCaps(LPDIRECTDRAW4 This, LPDDCAPS pDDC1, LPDDCAPS pDDC2)
 {
@@ -662,6 +857,15 @@ IDirectDraw2Impl_GetDisplayMode(LPDIRECTDRAW2 This, LPDDSURFACEDESC pDDSD)
 				       (LPDDSURFACEDESC2)pDDSD);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_GetDisplayMode(LPDIRECTDRAW3 This, LPDDSURFACEDESC pDDSD)
+{
+    return IDirectDraw7_GetDisplayMode(COM_INTERFACE_CAST(IDirectDrawImpl,
+							  IDirectDraw3,
+							  IDirectDraw7, This),
+				       (LPDDSURFACEDESC2)pDDSD);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_GetDisplayMode(LPDIRECTDRAW4 This, LPDDSURFACEDESC2 pDDSD)
 {
@@ -693,6 +897,17 @@ IDirectDraw2Impl_GetFourCCCodes(LPDIRECTDRAW2 This, LPDWORD lpNumCodes,
 				       lpNumCodes, lpCodes);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_GetFourCCCodes(LPDIRECTDRAW3 This, LPDWORD lpNumCodes,
+				LPDWORD lpCodes)
+{
+    return IDirectDraw7_GetFourCCCodes(COM_INTERFACE_CAST(IDirectDrawImpl,
+							  IDirectDraw3,
+							  IDirectDraw7,
+							  This),
+				       lpNumCodes, lpCodes);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_GetFourCCCodes(LPDIRECTDRAW4 This, LPDWORD lpNumCodes,
 				LPDWORD lpCodes)
@@ -742,6 +957,25 @@ IDirectDraw2Impl_GetGDISurface(LPDIRECTDRAW2 This, LPDIRECTDRAWSURFACE *ppSurf)
     return hr;
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_GetGDISurface(LPDIRECTDRAW3 This, LPDIRECTDRAWSURFACE *ppSurf)
+{
+    LPDIRECTDRAWSURFACE7 pSurf7;
+    HRESULT hr;
+
+    hr = IDirectDraw7_GetGDISurface(COM_INTERFACE_CAST(IDirectDrawImpl,
+						       IDirectDraw3,
+						       IDirectDraw7,
+						       This), &pSurf7);
+
+    /* This coercion is safe, since the IDirectDrawSurface3 vtable has the
+     * IDirectDrawSurface vtable layout at the beginning  */
+    *ppSurf = (LPDIRECTDRAWSURFACE)COM_INTERFACE_CAST(IDirectDrawSurfaceImpl, IDirectDrawSurface7,
+				 IDirectDrawSurface3, pSurf7);
+
+    return hr;
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_GetGDISurface(LPDIRECTDRAW4 This,
 			       LPDIRECTDRAWSURFACE4 *ppSurf)
@@ -773,6 +1007,16 @@ IDirectDraw2Impl_GetMonitorFrequency(LPDIRECTDRAW2 This, LPDWORD pdwFreq)
 					    pdwFreq);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_GetMonitorFrequency(LPDIRECTDRAW3 This, LPDWORD pdwFreq)
+{
+    return IDirectDraw7_GetMonitorFrequency(COM_INTERFACE_CAST(IDirectDrawImpl,
+							       IDirectDraw3,
+							       IDirectDraw7,
+							       This),
+					    pdwFreq);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_GetMonitorFrequency(LPDIRECTDRAW4 This, LPDWORD pdwFreq)
 {
@@ -801,6 +1045,15 @@ IDirectDraw2Impl_GetScanLine(LPDIRECTDRAW2 This, LPDWORD pdwLine)
 						       This), pdwLine);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_GetScanLine(LPDIRECTDRAW3 This, LPDWORD pdwLine)
+{
+    return IDirectDraw7_GetScanLine(COM_INTERFACE_CAST(IDirectDrawImpl,
+						       IDirectDraw3,
+						       IDirectDraw7,
+						       This), pdwLine);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_GetScanLine(LPDIRECTDRAW4 This, LPDWORD pdwLine)
 {
@@ -830,6 +1083,16 @@ IDirectDraw2Impl_GetVerticalBlankStatus(LPDIRECTDRAW2 This, LPBOOL lpbIsInVB)
 					       lpbIsInVB);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_GetVerticalBlankStatus(LPDIRECTDRAW3 This, LPBOOL lpbIsInVB)
+{
+    return IDirectDraw7_GetVerticalBlankStatus(COM_INTERFACE_CAST(IDirectDrawImpl,
+								  IDirectDraw3,
+								  IDirectDraw7,
+								  This),
+					       lpbIsInVB);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_GetVerticalBlankStatus(LPDIRECTDRAW4 This, LPBOOL lpbIsInVB)
 {
@@ -862,6 +1125,17 @@ IDirectDraw2Impl_Initialize(LPDIRECTDRAW2 iface, LPGUID pGUID)
     return ret_value;
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_Initialize(LPDIRECTDRAW3 iface, LPGUID pGUID)
+{
+    ICOM_THIS_FROM(IDirectDrawImpl, IDirectDraw3, iface);
+    HRESULT ret_value;
+
+    ret_value = IDirectDraw7_Initialize(ICOM_INTERFACE(This, IDirectDraw7), pGUID);
+
+    return ret_value;
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_Initialize(LPDIRECTDRAW4 iface, LPGUID pGUID)
 {
@@ -892,6 +1166,15 @@ IDirectDraw2Impl_RestoreDisplayMode(LPDIRECTDRAW2 This)
 							      This));
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_RestoreDisplayMode(LPDIRECTDRAW3 This)
+{
+    return IDirectDraw7_RestoreDisplayMode(COM_INTERFACE_CAST(IDirectDrawImpl,
+							      IDirectDraw3,
+							      IDirectDraw7,
+							      This));
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_RestoreDisplayMode(LPDIRECTDRAW4 This)
 {
@@ -923,6 +1206,17 @@ IDirectDraw2Impl_SetCooperativeLevel(LPDIRECTDRAW2 This, HWND hWnd,
 					    hWnd, dwFlags);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_SetCooperativeLevel(LPDIRECTDRAW3 This, HWND hWnd,
+				     DWORD dwFlags)
+{
+    return IDirectDraw7_SetCooperativeLevel(COM_INTERFACE_CAST(IDirectDrawImpl,
+							       IDirectDraw3,
+							       IDirectDraw7,
+							       This),
+					    hWnd, dwFlags);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_SetCooperativeLevel(LPDIRECTDRAW4 This, HWND hWnd,
 				     DWORD dwFlags)
@@ -955,6 +1249,17 @@ IDirectDraw2Impl_SetDisplayMode(LPDIRECTDRAW2 This, DWORD a, DWORD b, DWORD c,
 				       a, b, c, d, e);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_SetDisplayMode(LPDIRECTDRAW3 This, DWORD a, DWORD b, DWORD c,
+				DWORD d, DWORD e)
+{
+    return IDirectDraw7_SetDisplayMode(COM_INTERFACE_CAST(IDirectDrawImpl,
+							  IDirectDraw3,
+							  IDirectDraw7,
+							  This),
+				       a, b, c, d, e);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_SetDisplayMode(LPDIRECTDRAW4 This, DWORD a, DWORD b, DWORD c,
 				DWORD d, DWORD e)
@@ -988,6 +1293,17 @@ IDirectDraw2Impl_WaitForVerticalBlank(LPDIRECTDRAW2 This, DWORD dwFlags,
 					     dwFlags, hEvent);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_WaitForVerticalBlank(LPDIRECTDRAW3 This, DWORD dwFlags,
+				      HANDLE hEvent)
+{
+    return IDirectDraw7_WaitForVerticalBlank(COM_INTERFACE_CAST(IDirectDrawImpl,
+								IDirectDraw3,
+								IDirectDraw7,
+								This),
+					     dwFlags, hEvent);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_WaitForVerticalBlank(LPDIRECTDRAW4 This, DWORD dwFlags,
 				      HANDLE hEvent)
@@ -1013,6 +1329,20 @@ IDirectDraw2Impl_GetAvailableVidMem(LPDIRECTDRAW2 This, LPDDSCAPS pCaps,
 					   &Caps2, pdwTotal, pdwFree);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_GetAvailableVidMem(LPDIRECTDRAW3 This, LPDDSCAPS pCaps,
+				    LPDWORD pdwTotal, LPDWORD pdwFree)
+{
+    DDSCAPS2 Caps2;
+    DDRAW_Convert_DDSCAPS_1_To_2(pCaps, &Caps2);
+
+    return IDirectDraw7_GetAvailableVidMem(COM_INTERFACE_CAST(IDirectDrawImpl,
+							      IDirectDraw3,
+							      IDirectDraw7,
+							      This),
+					   &Caps2, pdwTotal, pdwFree);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_GetAvailableVidMem(LPDIRECTDRAW4 This, LPDDSCAPS2 pCaps,
 				    LPDWORD pdwTotal, LPDWORD pdwFree)
@@ -1024,6 +1354,17 @@ IDirectDraw4Impl_GetAvailableVidMem(LPDIRECTDRAW4 This, LPDDSCAPS2 pCaps,
 					   pCaps, pdwTotal, pdwFree);
 }
 
+static HRESULT WINAPI
+IDirectDraw3Impl_GetSurfaceFromDC(LPDIRECTDRAW3 This, HDC hDC,
+				  LPDIRECTDRAWSURFACE *pSurf)
+{
+    return IDirectDraw7_GetSurfaceFromDC(COM_INTERFACE_CAST(IDirectDrawImpl,
+							    IDirectDraw3,
+							    IDirectDraw7,
+							    This),
+					 hDC, (LPDIRECTDRAWSURFACE7 *)pSurf);
+}
+
 static HRESULT WINAPI
 IDirectDraw4Impl_GetSurfaceFromDC(LPDIRECTDRAW4 This, HDC hDC,
 				  LPDIRECTDRAWSURFACE4 *pSurf)
@@ -1126,6 +1467,35 @@ const IDirectDraw2Vtbl IDirectDraw2_Vtbl =
     IDirectDraw2Impl_GetAvailableVidMem
 };
 
+const IDirectDraw3Vtbl IDirectDraw3_Vtbl =
+{
+    IDirectDraw3Impl_QueryInterface,
+    IDirectDraw3Impl_AddRef,
+    IDirectDraw3Impl_Release,
+    IDirectDraw3Impl_Compact,
+    IDirectDraw3Impl_CreateClipper,
+    IDirectDraw3Impl_CreatePalette,
+    IDirectDraw3Impl_CreateSurface,
+    IDirectDraw3Impl_DuplicateSurface,
+    IDirectDraw3Impl_EnumDisplayModes,
+    IDirectDraw3Impl_EnumSurfaces,
+    IDirectDraw3Impl_FlipToGDISurface,
+    IDirectDraw3Impl_GetCaps,
+    IDirectDraw3Impl_GetDisplayMode,
+    IDirectDraw3Impl_GetFourCCCodes,
+    IDirectDraw3Impl_GetGDISurface,
+    IDirectDraw3Impl_GetMonitorFrequency,
+    IDirectDraw3Impl_GetScanLine,
+    IDirectDraw3Impl_GetVerticalBlankStatus,
+    IDirectDraw3Impl_Initialize,
+    IDirectDraw3Impl_RestoreDisplayMode,
+    IDirectDraw3Impl_SetCooperativeLevel,
+    IDirectDraw3Impl_SetDisplayMode,
+    IDirectDraw3Impl_WaitForVerticalBlank,
+    IDirectDraw3Impl_GetAvailableVidMem,
+    IDirectDraw3Impl_GetSurfaceFromDC,
+};
+
 const IDirectDraw4Vtbl IDirectDraw4_Vtbl =
 {
     IDirectDraw4Impl_QueryInterface,
