@@ -149,6 +149,7 @@ DDRAW_Create(GUID *guid,
      */
     ICOM_INIT_INTERFACE(This, IDirectDraw,  IDirectDraw1_Vtbl);
     ICOM_INIT_INTERFACE(This, IDirectDraw2, IDirectDraw2_Vtbl);
+    ICOM_INIT_INTERFACE(This, IDirectDraw3, IDirectDraw3_Vtbl);
     ICOM_INIT_INTERFACE(This, IDirectDraw4, IDirectDraw4_Vtbl);
     ICOM_INIT_INTERFACE(This, IDirectDraw7, IDirectDraw7_Vtbl);
     ICOM_INIT_INTERFACE(This, IDirect3D,  IDirect3D1_Vtbl);
@@ -315,6 +316,8 @@ DDRAW_Create(GUID *guid,
 #undef CKEY_CAPS
 #undef FX_CAPS
 
+    list_init(&This->surface_list);
+
     EnterCriticalSection(&ddraw_list_cs);
     list_add_head(&global_ddraw_list, &This->ddraw_list_entry);
     LeaveCriticalSection(&ddraw_list_cs);
@@ -879,11 +882,12 @@ DllMain(HINSTANCE hInstDLL,
                 int i;
                 IDirectDrawImpl *ddraw = LIST_ENTRY(entry, IDirectDrawImpl, ddraw_list_entry);
 
-                WARN("DDraw %p has a refcount of %d\n", ddraw, ddraw->ref7 + ddraw->ref4 + ddraw->ref2 + ddraw->ref1);
+                WARN("DDraw %p has a refcount of %d\n", ddraw, ddraw->ref7 + ddraw->ref4 + ddraw->ref3 + ddraw->ref2 + ddraw->ref1);
 
                 /* Add references to each interface to avoid freeing them unexpectadely */
                 IDirectDraw_AddRef(ICOM_INTERFACE(ddraw, IDirectDraw));
                 IDirectDraw2_AddRef(ICOM_INTERFACE(ddraw, IDirectDraw2));
+                IDirectDraw3_AddRef(ICOM_INTERFACE(ddraw, IDirectDraw3));
                 IDirectDraw4_AddRef(ICOM_INTERFACE(ddraw, IDirectDraw4));
                 IDirectDraw7_AddRef(ICOM_INTERFACE(ddraw, IDirectDraw7));
 
@@ -922,6 +926,7 @@ DllMain(HINSTANCE hInstDLL,
                     */
                 while(IDirectDraw_Release(ICOM_INTERFACE(ddraw, IDirectDraw)));
                 while(IDirectDraw2_Release(ICOM_INTERFACE(ddraw, IDirectDraw2)));
+                while(IDirectDraw3_Release(ICOM_INTERFACE(ddraw, IDirectDraw3)));
                 while(IDirectDraw4_Release(ICOM_INTERFACE(ddraw, IDirectDraw4)));
                 while(IDirectDraw7_Release(ICOM_INTERFACE(ddraw, IDirectDraw7)));
             }
