@@ -25,5 +25,14 @@
 /* ## DLL-wide Globals ## */
 extern HINSTANCE LOCALSPL_hInstance;
 
+/* ## Resource-ID ## */
+#define IDS_LOCALPORT       500
+#define IDS_LOCALMONITOR    507
+#define IDS_NOTHINGTOCONFIG 508
+
+/* ## Reserved memorysize for the strings (in WCHAR) ## */
+#define IDS_LOCALMONITOR_MAXLEN 64
+#define IDS_LOCALPORT_MAXLEN 32
+#define IDS_NOTHINGTOCONFIG_MAXLEN 80
 
 #endif /* __WINE_LOCALSPL_PRIVATE__ */
