@@ -21,6 +21,8 @@
 #include "mshtmhst.h"
 #include "hlink.h"
 
+#include "wine/list.h"
+
 #ifdef INIT_GUID
 #include "initguid.h"
 #endif
@@ -59,6 +61,8 @@ typedef struct {
 
     HTMLDocument *doc;
     nsIDOMWindow *nswindow;
+
+    struct list entry;
 } HTMLWindow;
 
 typedef enum {
@@ -328,6 +332,7 @@ void *nsalloc(size_t);
 void nsfree(void*);
 
 void nsACString_Init(nsACString*,const char*);
+void nsACString_SetData(nsACString*,const char*);
 PRUint32 nsACString_GetData(const nsACString*,const char**,PRBool*);
 void nsACString_Finish(nsACString*);
 
