@@ -115,6 +115,7 @@ static BOOL expect_LockContainer_fLock;
 static BOOL expect_SetActiveObject_active;
 static BOOL set_clientsite = FALSE, container_locked = FALSE;
 static BOOL readystate_set_loading = FALSE;
+static BOOL editmode = FALSE;
 static enum load_state_t {
     LD_DOLOAD,
     LD_LOADING,
@@ -127,6 +128,7 @@ static LPCOLESTR expect_status_text = NULL;
 
 static HRESULT QueryInterface(REFIID riid, void **ppv);
 static void test_readyState(IUnknown*);
+static void test_MSHTML_QueryStatus(IUnknown*,DWORD);
 
 static HRESULT WINAPI HlinkFrame_QueryInterface(IHlinkFrame *iface, REFIID riid, void **ppv)
 {
@@ -249,6 +251,10 @@ static HRESULT WINAPI PropertyNotifySink_OnChanged(IPropertyNotifySink *iface, D
     switch(dispID) {
     case DISPID_READYSTATE:
         CHECK_EXPECT2(OnChanged_READYSTATE);
+        test_MSHTML_QueryStatus(NULL, OLECMDF_SUPPORTED
+            | (editmode && (load_state == LD_INTERACTIVE || load_state == LD_COMPLETE)
+               ? OLECMDF_ENABLED : 0));
+
         if(readystate_set_loading) {
             readystate_set_loading = FALSE;
             load_state = LD_LOADING;
@@ -1804,24 +1810,33 @@ static void test_Load(IPersistMoniker *persist)
                                  (IUnknown*)&ClientSite);
 
     SET_EXPECT(GetDisplayName);
-    SET_EXPECT(GetHostInfo);
-    SET_EXPECT(Invoke_AMBIENT_USERMODE);
-    SET_EXPECT(Invoke_AMBIENT_SILENT);
-    SET_EXPECT(Invoke_AMBIENT_DLCONTROL);
-    SET_EXPECT(Invoke_AMBIENT_OFFLINEIFNOTCONNECTED);
-    SET_EXPECT(Invoke_AMBIENT_USERAGENT);
-    SET_EXPECT(Invoke_AMBIENT_PALETTE);
-    SET_EXPECT(GetOptionKeyPath);
-    SET_EXPECT(GetOverrideKeyPath);
-    SET_EXPECT(GetWindow);
-    SET_EXPECT(QueryStatus_SETPROGRESSTEXT);
-    SET_EXPECT(Exec_SETPROGRESSMAX);
-    SET_EXPECT(Exec_SETPROGRESSPOS);
-    SET_EXPECT(Exec_ShellDocView_37);
+    if(!set_clientsite) {
+        SET_EXPECT(Invoke_AMBIENT_USERMODE);
+        SET_EXPECT(GetHostInfo);
+        SET_EXPECT(Invoke_AMBIENT_DLCONTROL);
+        SET_EXPECT(Invoke_AMBIENT_SILENT);
+        SET_EXPECT(Invoke_AMBIENT_OFFLINEIFNOTCONNECTED);
+        SET_EXPECT(Invoke_AMBIENT_USERAGENT);
+        SET_EXPECT(Invoke_AMBIENT_PALETTE);
+        SET_EXPECT(GetOptionKeyPath);
+        SET_EXPECT(GetOverrideKeyPath);
+        SET_EXPECT(GetWindow);
+        SET_EXPECT(QueryStatus_SETPROGRESSTEXT);
+        SET_EXPECT(Exec_SETPROGRESSMAX);
+        SET_EXPECT(Exec_SETPROGRESSPOS);
+        SET_EXPECT(Exec_ShellDocView_37);
+    }
+    if(!container_locked) {
+        SET_EXPECT(GetContainer);
+        SET_EXPECT(LockContainer);
+    }
     SET_EXPECT(OnChanged_READYSTATE);
     SET_EXPECT(BindToStorage);
-    SET_EXPECT(GetContainer);
-    SET_EXPECT(LockContainer);
+    if(set_clientsite) {
+        SET_EXPECT(Invoke_AMBIENT_SILENT);
+        SET_EXPECT(Invoke_AMBIENT_OFFLINEIFNOTCONNECTED);
+        SET_EXPECT(Exec_ShellDocView_37);
+    }
     expect_LockContainer_fLock = TRUE;
     readystate_set_loading = TRUE;
 
@@ -1829,24 +1844,34 @@ static void test_Load(IPersistMoniker *persist)
     ok(hres == S_OK, "Load failed: %08x\n", hres);
 
     CHECK_CALLED(GetDisplayName);
-    CHECK_CALLED(GetHostInfo);
-    CHECK_CALLED(Invoke_AMBIENT_USERMODE);
-    CHECK_CALLED(Invoke_AMBIENT_SILENT);
-    CHECK_CALLED(Invoke_AMBIENT_DLCONTROL);
-    CHECK_CALLED(Invoke_AMBIENT_OFFLINEIFNOTCONNECTED);
-    CHECK_CALLED(Invoke_AMBIENT_USERAGENT);
-    CHECK_CALLED(Invoke_AMBIENT_PALETTE);
-    CHECK_CALLED(GetOptionKeyPath);
-    CHECK_CALLED(GetOverrideKeyPath);
-    CHECK_CALLED(GetWindow);
-    CHECK_CALLED(QueryStatus_SETPROGRESSTEXT);
-    CHECK_CALLED(Exec_SETPROGRESSMAX);
-    CHECK_CALLED(Exec_SETPROGRESSPOS);
-    CHECK_CALLED(Exec_ShellDocView_37);
+    if(!set_clientsite) {
+        CHECK_CALLED(Invoke_AMBIENT_USERMODE);
+        CHECK_CALLED(GetHostInfo);
+        CHECK_CALLED(Invoke_AMBIENT_DLCONTROL);
+        CHECK_CALLED(Invoke_AMBIENT_SILENT);
+        CHECK_CALLED(Invoke_AMBIENT_OFFLINEIFNOTCONNECTED);
+        CHECK_CALLED(Invoke_AMBIENT_USERAGENT);
+        CHECK_CALLED(Invoke_AMBIENT_PALETTE);
+        CHECK_CALLED(GetOptionKeyPath);
+        CHECK_CALLED(GetOverrideKeyPath);
+        CHECK_CALLED(GetWindow);
+        CHECK_CALLED(QueryStatus_SETPROGRESSTEXT);
+        CHECK_CALLED(Exec_SETPROGRESSMAX);
+        CHECK_CALLED(Exec_SETPROGRESSPOS);
+        CHECK_CALLED(Exec_ShellDocView_37);
+    }
+    if(!container_locked) {
+        CHECK_CALLED(GetContainer);
+        CHECK_CALLED(LockContainer);
+        container_locked = TRUE;
+    }
     CHECK_CALLED(OnChanged_READYSTATE);
     CHECK_CALLED(BindToStorage);
-    CHECK_CALLED(GetContainer);
-    CHECK_CALLED(LockContainer);
+    if(set_clientsite) {
+        CHECK_CALLED(Invoke_AMBIENT_SILENT);
+        CHECK_CALLED(Invoke_AMBIENT_OFFLINEIFNOTCONNECTED);
+        CHECK_CALLED(Exec_ShellDocView_37);
+    }
 
     set_clientsite = container_locked = TRUE;
 
@@ -1855,7 +1880,7 @@ static void test_Load(IPersistMoniker *persist)
     test_readyState((IUnknown*)persist);
 }
 
-static void test_download(void)
+static void test_download(BOOL verb_done)
 {
     HWND hwnd;
     MSG msg;
@@ -1865,6 +1890,10 @@ static void test_download(void)
 
     test_readyState(NULL);
 
+    if(verb_done) {
+        SET_EXPECT(Exec_SETPROGRESSMAX);
+        SET_EXPECT(GetHostInfo);
+    }
     SET_EXPECT(SetStatusText);
     SET_EXPECT(Exec_SETDOWNLOADSTATE_1);
     SET_EXPECT(GetDropTarget);
@@ -1882,6 +1911,10 @@ static void test_download(void)
         DispatchMessage(&msg);
     }
 
+    if(verb_done) {
+        CHECK_CALLED(Exec_SETPROGRESSMAX);
+        CHECK_CALLED(GetHostInfo);
+    }
     CHECK_CALLED(SetStatusText);
     CHECK_CALLED(Exec_SETDOWNLOADSTATE_1);
     CHECK_CALLED(GetDropTarget);
@@ -1979,6 +2012,49 @@ static const OLECMDF expect_cmds[OLECMDID_GETPRINTTEMPLATE+1] = {
     OLECMDF_SUPPORTED                   /* OLECMDID_GETPRINTTEMPLATE */
 };
 
+static void test_QueryStatus(IUnknown *unk, REFIID cgid, ULONG cmdid, DWORD cmdf)
+{
+    IOleCommandTarget *cmdtrg;
+    OLECMD olecmd = {cmdid, 0};
+    HRESULT hres;
+
+    hres = IUnknown_QueryInterface(unk, &IID_IOleCommandTarget, (void**)&cmdtrg);
+    ok(hres == S_OK, "QueryInterface(IID_IOleCommandTarget failed: %08x\n", hres);
+    if(FAILED(hres))
+        return;
+
+    hres = IOleCommandTarget_QueryStatus(cmdtrg, cgid, 1, &olecmd, NULL);
+    ok(hres == S_OK, "QueryStatus failed: %08x\n", hres);
+
+    IOleCommandTarget_Release(cmdtrg);
+
+    ok(olecmd.cmdID == cmdid, "cmdID changed\n");
+    ok(olecmd.cmdf == cmdf, "cmdf=%08x, expected %08x\n", olecmd.cmdf, cmdf);
+}
+
+static void test_MSHTML_QueryStatus(IUnknown *unk, DWORD cmdf)
+{
+    static IUnknown *_unk;
+
+    if(unk) _unk = unk;
+    else unk = _unk;
+
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_FONTNAME, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_FONTSIZE, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_BOLD, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_FORECOLOR, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_JUSTIFYCENTER, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_JUSTIFYLEFT, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_JUSTIFYRIGHT, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_ITALIC, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_UNDERLINE, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_HORIZONTALLINE, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_ORDERLIST, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_UNORDERLIST, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_INDENT, cmdf);
+    test_QueryStatus(unk, &CGID_MSHTML, IDM_OUTDENT, cmdf);
+}
+
 static void test_OleCommandTarget(IUnknown *unk)
 {
     IOleCommandTarget *cmdtrg;
@@ -1987,7 +2063,7 @@ static void test_OleCommandTarget(IUnknown *unk)
     HRESULT hres;
 
     hres = IUnknown_QueryInterface(unk, &IID_IOleCommandTarget, (void**)&cmdtrg);
-    ok(hres == S_OK, "QueryInterface(IIDIOleM=CommandTarget failed: %08x\n", hres);
+    ok(hres == S_OK, "QueryInterface(IID_IOleCommandTarget failed: %08x\n", hres);
     if(FAILED(hres))
         return;
 
@@ -2120,6 +2196,8 @@ static void test_exec_editmode(IUnknown *unk)
     CHECK_CALLED(OnChanged_READYSTATE);
 
     IOleCommandTarget_Release(cmdtrg);
+
+    editmode = TRUE;
 }
 
 static HWND create_container_window(void)
@@ -2550,6 +2628,7 @@ static void init_test(enum load_state_t ls) {
     set_clientsite = FALSE;
     call_UIActivate = FALSE;
     load_state = ls;
+    editmode = FALSE;
 }
 
 static void test_HTMLDocument(enum load_state_t ls)
@@ -2567,6 +2646,7 @@ static void test_HTMLDocument(enum load_state_t ls)
         return;
 
     test_QueryInterface(unk);
+    test_MSHTML_QueryStatus(unk, OLECMDF_SUPPORTED);
     test_ConnectionPointContainer(unk);
     test_Persist(unk);
     if(load_state == LD_NO)
@@ -2579,8 +2659,9 @@ static void test_HTMLDocument(enum load_state_t ls)
     }
 
     if(load_state == LD_LOADING)
-        test_download();
+        test_download(FALSE);
 
+    test_MSHTML_QueryStatus(unk, OLECMDF_SUPPORTED);
     test_OleCommandTarget_fail(unk);
     test_OleCommandTarget(unk);
     test_OnAmbientPropertyChange(unk);
@@ -2648,8 +2729,9 @@ static void test_HTMLDocument_hlink(void)
     test_Persist(unk);
     test_Navigate(unk);
 
-    test_download();
+    test_download(FALSE);
 
+    test_MSHTML_QueryStatus(unk, OLECMDF_SUPPORTED);
     test_exec_onunload(unk);
     test_Window(unk, TRUE);
     test_InPlaceDeactivate(unk, TRUE);
@@ -2685,10 +2767,14 @@ static void test_editing_mode(void)
     test_ConnectionPointContainer(unk);
     test_ClientSite(oleobj, CLIENTSITE_EXPECTPATH);
     test_DoVerb(oleobj);
+    test_MSHTML_QueryStatus(unk, OLECMDF_SUPPORTED);
 
     IOleObject_Release(oleobj);
 
     test_exec_editmode(unk);
+    test_MSHTML_QueryStatus(unk, OLECMDF_SUPPORTED);
+    test_download(TRUE);
+    test_MSHTML_QueryStatus(unk, OLECMDF_SUPPORTED|OLECMDF_ENABLED);
 
     test_UIDeactivate();
     test_InPlaceDeactivate(unk, TRUE);
