@@ -19,6 +19,7 @@
  */
 
 #include <stdarg.h>
+#include <assert.h>
 
 #define COBJMACROS
 #define NONAMELESSUNION
@@ -34,7 +35,6 @@
 #include "winnls.h"
 #include "msipriv.h"
 #include "query.h"
-#include "assert.h"
 
 #include "wine/debug.h"
 #include "wine/unicode.h"
@@ -1587,12 +1587,12 @@ static UINT TABLE_find_matching_rows( struct tagMSIVIEW *view, UINT col,
     if( !*handle )
         entry = tv->columns[col-1].hash_table[val % MSITABLE_HASH_TABLE_SIZE];
     else
-        entry = ((const MSICOLUMNHASHENTRY *)*handle)->next;
+        entry = (*handle)->next;
 
     while (entry && entry->value != val)
         entry = entry->next;
 
-    *handle = (MSIITERHANDLE)entry;
+    *handle = entry;
     if (!entry)
         return ERROR_NO_MORE_ITEMS;
 
@@ -2065,7 +2065,7 @@ UINT msi_table_apply_transform( MSIDATABASE *db, IStorage *stg )
         goto end;
 
     /*
-     * Apply _Tables and _Coluimns transforms first so that
+     * Apply _Tables and _Columns transforms first so that
      * the table metadata is correct, and empty tables exist.
      */
     ret = msi_table_load_transform( db, stg, strings, szTables );
@@ -2101,14 +2101,7 @@ UINT msi_table_apply_transform( MSIDATABASE *db, IStorage *stg )
     }
 
     if ( ret == ERROR_SUCCESS )
-    {
-        MSITRANSFORM *t;
-
-        t = msi_alloc( sizeof *t );
-        t->stg = stg;
-        IStorage_AddRef( stg );
-        list_add_tail( &db->transforms, &t->entry );
-    }
+        append_storage_to_db( db, stg );
 
 end:
     if ( stgenum )
@@ -2119,6 +2112,16 @@ end:
     return ret;
 }
 
+void append_storage_to_db( MSIDATABASE *db, IStorage *stg )
+{
+    MSITRANSFORM *t;
+
+    t = msi_alloc( sizeof *t );
+    t->stg = stg;
+    IStorage_AddRef( stg );
+    list_add_tail( &db->transforms, &t->entry );
+}
+
 void msi_free_transforms( MSIDATABASE *db )
 {
     while( !list_empty( &db->transforms ) )
