@@ -43,10 +43,10 @@ WINE_DEFAULT_DEBUG_CHANNEL(seh);
 
 #ifdef __i386__  /* CxxFrameHandler is not supported on non-i386 */
 
-DWORD cxx_frame_handler( PEXCEPTION_RECORD rec, cxx_exception_frame* frame,
-                         PCONTEXT context, EXCEPTION_REGISTRATION_RECORD** dispatch,
-                         cxx_function_descr *descr, EXCEPTION_REGISTRATION_RECORD* nested_frame,
-                         int nested_trylevel );
+DWORD CDECL cxx_frame_handler( PEXCEPTION_RECORD rec, cxx_exception_frame* frame,
+                               PCONTEXT context, EXCEPTION_REGISTRATION_RECORD** dispatch,
+                               const cxx_function_descr *descr,
+                               EXCEPTION_REGISTRATION_RECORD* nested_frame, int nested_trylevel );
 
 /* call a function with a given ebp */
 inline static void *call_ebp_func( void *func, void *ebp )
@@ -112,7 +112,7 @@ static void dump_exception_type( const cxx_exception_type *type )
     }
 }
 
-static void dump_function_descr( const cxx_function_descr *descr, const cxx_exception_type *info )
+static void dump_function_descr( const cxx_function_descr *descr )
 {
     UINT i;
     int j;
@@ -133,7 +133,7 @@ static void dump_function_descr( const cxx_function_descr *descr, const cxx_exce
                  descr->tryblock[i].catchblock_count );
         for (j = 0; j < descr->tryblock[i].catchblock_count; j++)
         {
-            catchblock_info *ptr = &descr->tryblock[i].catchblock[j];
+            const catchblock_info *ptr = &descr->tryblock[i].catchblock[j];
             TRACE( "        %d: flags %x offset %d handler %p type %p %s\n",
                      j, ptr->flags, ptr->offset, ptr->handler,
                      ptr->type_info, dbgstr_type_info( ptr->type_info ) );
@@ -142,7 +142,8 @@ static void dump_function_descr( const cxx_function_descr *descr, const cxx_exce
 }
 
 /* check if the exception type is caught by a given catch block, and return the type that matched */
-static const cxx_type_info *find_caught_type( cxx_exception_type *exc_type, catchblock_info *catchblock )
+static const cxx_type_info *find_caught_type( cxx_exception_type *exc_type,
+                                              const catchblock_info *catchblock )
 {
     UINT i;
 
@@ -168,7 +169,7 @@ static const cxx_type_info *find_caught_type( cxx_exception_type *exc_type, catc
 
 /* copy the exception object where the catch block wants it */
 static void copy_exception( void *object, cxx_exception_frame *frame,
-                            catchblock_info *catchblock, const cxx_type_info *type )
+                            const catchblock_info *catchblock, const cxx_type_info *type )
 {
     void **dest_ptr;
 
@@ -197,7 +198,7 @@ static void copy_exception( void *object, cxx_exception_frame *frame,
 }
 
 /* unwind the local function up to a given trylevel */
-static void cxx_local_unwind( cxx_exception_frame* frame, cxx_function_descr *descr, int last_level)
+static void cxx_local_unwind( cxx_exception_frame* frame, const cxx_function_descr *descr, int last_level)
 {
     void (*handler)();
     int trylevel = frame->trylevel;
@@ -227,7 +228,7 @@ struct catch_func_nested_frame
     EXCEPTION_REGISTRATION_RECORD frame;     /* standard exception frame */
     EXCEPTION_RECORD             *prev_rec;  /* previous record to restore in thread data */
     cxx_exception_frame          *cxx_frame; /* frame of parent exception */
-    cxx_function_descr           *descr;     /* descriptor of parent exception */
+    const cxx_function_descr     *descr;     /* descriptor of parent exception */
     int                           trylevel;  /* current try level */
     EXCEPTION_RECORD             *rec;       /* rec associated with frame */
 };
@@ -276,7 +277,7 @@ static DWORD catch_function_nested_handler( EXCEPTION_RECORD *rec, EXCEPTION_REG
 /* find and call the appropriate catch block for an exception */
 /* returns the address to continue execution to after the catch block was called */
 inline static void call_catch_block( PEXCEPTION_RECORD rec, cxx_exception_frame *frame,
-                                     cxx_function_descr *descr, int nested_trylevel,
+                                     const cxx_function_descr *descr, int nested_trylevel,
                                      cxx_exception_type *info )
 {
     UINT i;
@@ -289,7 +290,7 @@ inline static void call_catch_block( PEXCEPTION_RECORD rec, cxx_exception_frame
 
     for (i = 0; i < descr->tryblock_count; i++)
     {
-        tryblock_info *tryblock = &descr->tryblock[i];
+        const tryblock_info *tryblock = &descr->tryblock[i];
 
         if (trylevel < tryblock->start_level) continue;
         if (trylevel > tryblock->end_level) continue;
@@ -297,7 +298,7 @@ inline static void call_catch_block( PEXCEPTION_RECORD rec, cxx_exception_frame
         /* got a try block */
         for (j = 0; j < tryblock->catchblock_count; j++)
         {
-            catchblock_info *catchblock = &tryblock->catchblock[j];
+            const catchblock_info *catchblock = &tryblock->catchblock[j];
             if(info)
             {
                 const cxx_type_info *type = find_caught_type( info, catchblock );
@@ -355,10 +356,11 @@ inline static void call_catch_block( PEXCEPTION_RECORD rec, cxx_exception_frame
  *
  * Implementation of __CxxFrameHandler.
  */
-DWORD cxx_frame_handler( PEXCEPTION_RECORD rec, cxx_exception_frame* frame,
-                         PCONTEXT context, EXCEPTION_REGISTRATION_RECORD** dispatch,
-                         cxx_function_descr *descr, EXCEPTION_REGISTRATION_RECORD* nested_frame,
-                         int nested_trylevel )
+DWORD CDECL cxx_frame_handler( PEXCEPTION_RECORD rec, cxx_exception_frame* frame,
+                               PCONTEXT context, EXCEPTION_REGISTRATION_RECORD** dispatch,
+                               const cxx_function_descr *descr,
+                               EXCEPTION_REGISTRATION_RECORD* nested_frame,
+                               int nested_trylevel )
 {
     cxx_exception_type *exc_type;
 
@@ -390,13 +392,13 @@ DWORD cxx_frame_handler( PEXCEPTION_RECORD rec, cxx_exception_frame* frame,
             TRACE("handling C++ exception rec %p frame %p trylevel %d descr %p nested_frame %p\n",
                   rec, frame, frame->trylevel, descr, nested_frame );
             dump_exception_type( exc_type );
-            dump_function_descr( descr, exc_type );
+            dump_function_descr( descr );
         }
     }
     else
     {
         exc_type = NULL;
-        TRACE("handling C exception code %lx  rec %p frame %p trylevel %d descr %p nested_frame %p\n",
+        TRACE("handling C exception code %x  rec %p frame %p trylevel %d descr %p nested_frame %p\n",
               rec->ExceptionCode,  rec, frame, frame->trylevel, descr, nested_frame );
     }
 
@@ -408,8 +410,8 @@ DWORD cxx_frame_handler( PEXCEPTION_RECORD rec, cxx_exception_frame* frame,
 /*********************************************************************
  *		__CxxFrameHandler (MSVCRT.@)
  */
-extern DWORD __CxxFrameHandler( PEXCEPTION_RECORD rec, EXCEPTION_REGISTRATION_RECORD* frame,
-                                PCONTEXT context, EXCEPTION_REGISTRATION_RECORD** dispatch );
+extern DWORD CDECL __CxxFrameHandler( PEXCEPTION_RECORD rec, EXCEPTION_REGISTRATION_RECORD* frame,
+                                      PCONTEXT context, EXCEPTION_REGISTRATION_RECORD** dispatch );
 __ASM_GLOBAL_FUNC( __CxxFrameHandler,
                    "pushl $0\n\t"        /* nested_trylevel */
                    "pushl $0\n\t"        /* nested_frame */
@@ -422,12 +424,27 @@ __ASM_GLOBAL_FUNC( __CxxFrameHandler,
                    "add $28,%esp\n\t"
                    "ret" );
 
+
+/*********************************************************************
+ *		__CxxLongjmpUnwind (MSVCRT.@)
+ *
+ * Callback meant to be used as UnwindFunc for setjmp/longjmp.
+ */
+void __stdcall __CxxLongjmpUnwind( const struct MSVCRT___JUMP_BUFFER *buf )
+{
+    cxx_exception_frame *frame = (cxx_exception_frame *)buf->Registration;
+    const cxx_function_descr *descr = (const cxx_function_descr *)buf->UnwindData[0];
+
+    TRACE( "unwinding frame %p descr %p trylevel %ld\n", frame, descr, buf->TryLevel );
+    cxx_local_unwind( frame, descr, buf->TryLevel );
+}
+
 #endif  /* __i386__ */
 
 /*********************************************************************
  *		_CxxThrowException (MSVCRT.@)
  */
-void _CxxThrowException( exception *object, const cxx_exception_type *type )
+void CDECL _CxxThrowException( exception *object, const cxx_exception_type *type )
 {
     ULONG_PTR args[3];
 
@@ -440,7 +457,7 @@ void _CxxThrowException( exception *object, const cxx_exception_type *type )
 /*********************************************************************
  *		__CxxDetectRethrow (MSVCRT.@)
  */
-BOOL __CxxDetectRethrow(PEXCEPTION_POINTERS ptrs)
+BOOL CDECL __CxxDetectRethrow(PEXCEPTION_POINTERS ptrs)
 {
   PEXCEPTION_RECORD rec;
 
@@ -463,7 +480,7 @@ BOOL __CxxDetectRethrow(PEXCEPTION_POINTERS ptrs)
 /*********************************************************************
  *		__CxxQueryExceptionSize (MSVCRT.@)
  */
-unsigned int __CxxQueryExceptionSize(void)
+unsigned int CDECL __CxxQueryExceptionSize(void)
 {
   return sizeof(cxx_exception_type);
 }
