@@ -68,6 +68,16 @@ static CRITICAL_SECTION_DEBUG csRegIf_debug =
 };
 static CRITICAL_SECTION csRegIf = { &csRegIf_debug, -1, 0, 0, 0, 0 };
 
+static struct list channel_hooks = LIST_INIT(channel_hooks); /* (CS csChannelHook) */
+static CRITICAL_SECTION csChannelHook;
+static CRITICAL_SECTION_DEBUG csChannelHook_debug =
+{
+    0, 0, &csChannelHook,
+    { &csChannelHook_debug.ProcessLocksList, &csChannelHook_debug.ProcessLocksList },
+      0, 0, { (DWORD_PTR)(__FILE__ ": channel hooks") }
+};
+static CRITICAL_SECTION csChannelHook = { &csChannelHook_debug, -1, 0, 0, 0, 0 };
+
 static WCHAR wszRpcTransport[] = {'n','c','a','l','r','p','c',0};
 
 
@@ -108,11 +118,198 @@ struct dispatch_params
     RPCOLEMESSAGE     *msg; /* message */
     IRpcStubBuffer    *stub; /* stub buffer, if applicable */
     IRpcChannelBuffer *chan; /* server channel buffer, if applicable */
+    IID                iid; /* ID of interface being called */
+    IUnknown          *iface; /* interface being called */
     HANDLE             handle; /* handle that will become signaled when call finishes */
     RPC_STATUS         status; /* status (out) */
     HRESULT            hr; /* hresult (out) */
 };
 
+struct message_state
+{
+    RPC_BINDING_HANDLE binding_handle;
+    ULONG prefix_data_len;
+    SChannelHookCallInfo channel_hook_info;
+};
+
+typedef struct
+{
+    ULONG conformance; /* NDR */
+    GUID id;
+    ULONG size;
+    /* [size_is((size+7)&~7)] */ unsigned char data[1];
+} WIRE_ORPC_EXTENT;
+
+struct channel_hook_entry
+{
+    struct list entry;
+    GUID id;
+    IChannelHook *hook;
+};
+
+struct channel_hook_buffer_data
+{
+    GUID id;
+    ULONG extension_size;
+};
+
+
+/* Channel Hook Functions */
+
+static ULONG ChannelHooks_ClientGetSize(SChannelHookCallInfo *info,
+    struct channel_hook_buffer_data **data, unsigned int *hook_count,
+    ULONG *extension_count)
+{
+    struct channel_hook_entry *entry;
+    ULONG total_size = 0;
+    unsigned int hook_index = 0;
+
+    *hook_count = 0;
+    *extension_count = 0;
+
+    EnterCriticalSection(&csChannelHook);
+
+    LIST_FOR_EACH_ENTRY(entry, &channel_hooks, struct channel_hook_entry, entry)
+        (*hook_count)++;
+
+    if (hook_count)
+        *data = HeapAlloc(GetProcessHeap(), 0, *hook_count * sizeof(struct channel_hook_buffer_data));
+    else
+        *data = NULL;
+
+    LIST_FOR_EACH_ENTRY(entry, &channel_hooks, struct channel_hook_entry, entry)
+    {
+        ULONG extension_size = 0;
+
+        IChannelHook_ClientGetSize(entry->hook, &entry->id, &info->iid, &extension_size);
+
+        TRACE("%s: extension_size = %u\n", debugstr_guid(&entry->id), extension_size);
+
+        extension_size = (extension_size+7)&~7;
+        (*data)[hook_index].id = entry->id;
+        (*data)[hook_index].extension_size = extension_size;
+
+        /* an extension is only put onto the wire if it has data to write */
+        if (extension_size)
+        {
+            total_size += FIELD_OFFSET(WIRE_ORPC_EXTENT, data[extension_size]);
+            (*extension_count)++;
+        }
+
+        hook_index++;
+    }
+
+    LeaveCriticalSection(&csChannelHook);
+
+    return total_size;
+}
+
+static unsigned char * ChannelHooks_ClientFillBuffer(SChannelHookCallInfo *info,
+    unsigned char *buffer, struct channel_hook_buffer_data *data,
+    unsigned int hook_count)
+{
+    struct channel_hook_entry *entry;
+
+    EnterCriticalSection(&csChannelHook);
+
+    LIST_FOR_EACH_ENTRY(entry, &channel_hooks, struct channel_hook_entry, entry)
+    {
+        unsigned int i;
+        ULONG extension_size = 0;
+        WIRE_ORPC_EXTENT *wire_orpc_extent = (WIRE_ORPC_EXTENT *)buffer;
+
+        for (i = 0; i < hook_count; i++)
+            if (IsEqualGUID(&entry->id, &data[i].id))
+                extension_size = data[i].extension_size;
+
+        /* an extension is only put onto the wire if it has data to write */
+        if (!extension_size)
+            continue;
+
+        IChannelHook_ClientFillBuffer(entry->hook, &entry->id, &info->iid,
+            &extension_size, buffer + FIELD_OFFSET(WIRE_ORPC_EXTENT, data[0]));
+
+        TRACE("%s: extension_size = %u\n", debugstr_guid(&entry->id), extension_size);
+
+        /* FIXME: set unused portion of wire_orpc_extent->data to 0? */
+
+        wire_orpc_extent->conformance = (extension_size+7)&~7;
+        wire_orpc_extent->size = extension_size;
+        memcpy(&wire_orpc_extent->id, &entry->id, sizeof(wire_orpc_extent->id));
+        buffer += FIELD_OFFSET(WIRE_ORPC_EXTENT, data[wire_orpc_extent->conformance]);
+    }
+
+    LeaveCriticalSection(&csChannelHook);
+
+    HeapFree(GetProcessHeap(), 0, data);
+
+    return buffer;
+}
+
+static void ChannelHooks_ServerNotify(SChannelHookCallInfo *info,
+    DWORD lDataRep, WIRE_ORPC_EXTENT *first_wire_orpc_extent,
+    ULONG extension_count)
+{
+    struct channel_hook_entry *entry;
+    ULONG i;
+
+    EnterCriticalSection(&csChannelHook);
+
+    LIST_FOR_EACH_ENTRY(entry, &channel_hooks, struct channel_hook_entry, entry)
+    {
+        WIRE_ORPC_EXTENT *wire_orpc_extent;
+        for (i = 0, wire_orpc_extent = first_wire_orpc_extent;
+             i < extension_count;
+             i++, wire_orpc_extent = (WIRE_ORPC_EXTENT *)&wire_orpc_extent->data[wire_orpc_extent->conformance])
+        {
+            if (IsEqualGUID(&entry->id, &wire_orpc_extent->id))
+                break;
+        }
+        if (i == extension_count) wire_orpc_extent = NULL;
+
+        IChannelHook_ServerNotify(entry->hook, &entry->id, &info->iid,
+            wire_orpc_extent ? wire_orpc_extent->size : 0,
+            wire_orpc_extent ? wire_orpc_extent->data : NULL,
+            lDataRep);
+    }
+
+    LeaveCriticalSection(&csChannelHook);
+}
+
+HRESULT RPC_RegisterChannelHook(REFGUID rguid, IChannelHook *hook)
+{
+    struct channel_hook_entry *entry;
+
+    TRACE("(%s, %p)\n", debugstr_guid(rguid), hook);
+
+    entry = HeapAlloc(GetProcessHeap(), 0, sizeof(*entry));
+    if (!entry)
+        return E_OUTOFMEMORY;
+
+    memcpy(&entry->id, rguid, sizeof(entry->id));
+    entry->hook = hook;
+    IChannelHook_AddRef(hook);
+
+    EnterCriticalSection(&csChannelHook);
+    list_add_tail(&channel_hooks, &entry->entry);
+    LeaveCriticalSection(&csChannelHook);
+
+    return S_OK;
+}
+
+void RPC_UnregisterAllChannelHooks(void)
+{
+    struct channel_hook_entry *cursor;
+    struct channel_hook_entry *cursor2;
+
+    EnterCriticalSection(&csChannelHook);
+    LIST_FOR_EACH_ENTRY_SAFE(cursor, cursor2, &channel_hooks, struct channel_hook_entry, entry)
+        HeapFree(GetProcessHeap(), 0, cursor);
+    LeaveCriticalSection(&csChannelHook);
+}
+
+/* RPC Channel Buffer Functions */
+
 static HRESULT WINAPI RpcChannelBuffer_QueryInterface(LPRPCCHANNELBUFFER iface, REFIID riid, LPVOID *ppv)
 {
     *ppv = NULL;
@@ -164,11 +361,21 @@ static HRESULT WINAPI ServerRpcChannelBuffer_GetBuffer(LPRPCCHANNELBUFFER iface,
     RpcChannelBuffer *This = (RpcChannelBuffer *)iface;
     RPC_MESSAGE *msg = (RPC_MESSAGE *)olemsg;
     RPC_STATUS status;
+    struct message_state *message_state;
 
     TRACE("(%p)->(%p,%s)\n", This, olemsg, debugstr_guid(riid));
 
+    message_state = (struct message_state *)msg->Handle;
+    /* restore the binding handle and the real start of data */
+    msg->Handle = message_state->binding_handle;
+    msg->Buffer = (char *)msg->Buffer - message_state->prefix_data_len;
+
     status = I_RpcGetBuffer(msg);
 
+    /* save away the message state again */
+    msg->Handle = message_state;
+    message_state->prefix_data_len = 0;
+
     TRACE("-- %ld\n", status);
 
     return HRESULT_FROM_WIN32(status);
@@ -180,6 +387,12 @@ static HRESULT WINAPI ClientRpcChannelBuffer_GetBuffer(LPRPCCHANNELBUFFER iface,
     RPC_MESSAGE *msg = (RPC_MESSAGE *)olemsg;
     RPC_CLIENT_INTERFACE *cif;
     RPC_STATUS status;
+    ORPCTHIS *orpcthis;
+    struct message_state *message_state;
+    ULONG extensions_size;
+    struct channel_hook_buffer_data *channel_hook_data;
+    unsigned int channel_hook_count;
+    ULONG extension_count;
 
     TRACE("(%p)->(%p,%s)\n", This, olemsg, debugstr_guid(riid));
 
@@ -187,17 +400,95 @@ static HRESULT WINAPI ClientRpcChannelBuffer_GetBuffer(LPRPCCHANNELBUFFER iface,
     if (!cif)
         return E_OUTOFMEMORY;
 
+    message_state = HeapAlloc(GetProcessHeap(), 0, sizeof(*message_state));
+    if (!message_state)
+    {
+        HeapFree(GetProcessHeap(), 0, cif);
+        return E_OUTOFMEMORY;
+    }
+
     cif->Length = sizeof(RPC_CLIENT_INTERFACE);
     /* RPC interface ID = COM interface ID */
     cif->InterfaceId.SyntaxGUID = *riid;
     /* COM objects always have a version of 0.0 */
     cif->InterfaceId.SyntaxVersion.MajorVersion = 0;
     cif->InterfaceId.SyntaxVersion.MinorVersion = 0;
-    msg->RpcInterfaceInformation = cif;
     msg->Handle = This->bind;
-    
+    msg->RpcInterfaceInformation = cif;
+
+    message_state->channel_hook_info.iid = *riid;
+    message_state->channel_hook_info.cbSize = sizeof(message_state->channel_hook_info);
+    message_state->channel_hook_info.uCausality = COM_CurrentCausalityId();
+    message_state->channel_hook_info.dwServerPid = 0; /* FIXME */
+    message_state->channel_hook_info.iMethod = msg->ProcNum;
+    message_state->channel_hook_info.pObject = NULL; /* only present on server-side */
+
+    extensions_size = ChannelHooks_ClientGetSize(&message_state->channel_hook_info,
+        &channel_hook_data, &channel_hook_count, &extension_count);
+
+    msg->BufferLength += FIELD_OFFSET(ORPCTHIS, extensions) + 4;
+    if (extensions_size)
+    {
+        msg->BufferLength += FIELD_OFFSET(ORPC_EXTENT_ARRAY, extent) + 2*sizeof(DWORD) + extensions_size;
+        if (extension_count & 1)
+            msg->BufferLength += FIELD_OFFSET(WIRE_ORPC_EXTENT, data[0]);
+    }
+
     status = I_RpcGetBuffer(msg);
 
+    message_state->prefix_data_len = 0;
+    message_state->binding_handle = This->bind;
+    msg->Handle = message_state;
+
+    if (status == RPC_S_OK)
+    {
+        orpcthis = (ORPCTHIS *)msg->Buffer;
+        msg->Buffer = (char *)msg->Buffer + FIELD_OFFSET(ORPCTHIS, extensions);
+
+        orpcthis->version.MajorVersion = COM_MAJOR_VERSION;
+        orpcthis->version.MinorVersion = COM_MINOR_VERSION;
+        orpcthis->flags = message_state->channel_hook_info.dwServerPid ? ORPCF_LOCAL : ORPCF_NULL;
+        orpcthis->reserved1 = 0;
+        orpcthis->cid = message_state->channel_hook_info.uCausality;
+
+        /* NDR representation of orpcthis->extensions */
+        *(DWORD *)msg->Buffer = extensions_size ? 1 : 0;
+        msg->Buffer = (char *)msg->Buffer + sizeof(DWORD);
+
+        if (extensions_size)
+        {
+            ORPC_EXTENT_ARRAY *orpc_extent_array = msg->Buffer;
+            orpc_extent_array->size = extension_count;
+            orpc_extent_array->reserved = 0;
+            msg->Buffer = (char *)msg->Buffer + FIELD_OFFSET(ORPC_EXTENT_ARRAY, extent);
+            /* NDR representation of orpc_extent_array->extent */
+            *(DWORD *)msg->Buffer = 1;
+            msg->Buffer = (char *)msg->Buffer + sizeof(DWORD);
+            /* NDR representation of [size_is] attribute of orpc_extent_array->extent */
+            *(DWORD *)msg->Buffer = (extension_count + 1) & ~1;
+            msg->Buffer = (char *)msg->Buffer + sizeof(DWORD);
+
+            msg->Buffer = ChannelHooks_ClientFillBuffer(&message_state->channel_hook_info,
+                msg->Buffer, channel_hook_data, channel_hook_count);
+
+            /* we must add a dummy extension if there is an odd extension
+             * count to meet the contract specified by the size_is attribute */
+            if (extension_count & 1)
+            {
+                WIRE_ORPC_EXTENT *wire_orpc_extent = msg->Buffer;
+                wire_orpc_extent->conformance = 0;
+                memcpy(&wire_orpc_extent->id, &GUID_NULL, sizeof(wire_orpc_extent->id));
+                wire_orpc_extent->size = 0;
+                msg->Buffer = (char *)msg->Buffer + FIELD_OFFSET(WIRE_ORPC_EXTENT, data[0]);
+            }
+        }
+
+        /* store the prefixed data length so that we can restore the real buffer
+         * pointer in ClientRpcChannelBuffer_SendReceive. */
+        message_state->prefix_data_len = (char *)msg->Buffer - (char *)orpcthis;
+        msg->BufferLength -= message_state->prefix_data_len;
+    }
+
     TRACE("-- %ld\n", status);
 
     return HRESULT_FROM_WIN32(status);
@@ -264,6 +555,7 @@ static HRESULT WINAPI ClientRpcChannelBuffer_SendReceive(LPRPCCHANNELBUFFER ifac
     struct dispatch_params *params;
     APARTMENT *apt = NULL;
     IPID ipid;
+    struct message_state *message_state;
 
     TRACE("(%p) iMethod=%d\n", olemsg, olemsg->iMethod);
 
@@ -278,6 +570,12 @@ static HRESULT WINAPI ClientRpcChannelBuffer_SendReceive(LPRPCCHANNELBUFFER ifac
     params = HeapAlloc(GetProcessHeap(), HEAP_ZERO_MEMORY, sizeof(*params));
     if (!params) return E_OUTOFMEMORY;
 
+    message_state = (struct message_state *)msg->Handle;
+    /* restore the binding handle and the real start of data */
+    msg->Handle = message_state->binding_handle;
+    msg->Buffer = (char *)msg->Buffer - message_state->prefix_data_len;
+    msg->BufferLength += message_state->prefix_data_len;
+
     params->msg = olemsg;
     params->status = RPC_S_OK;
     params->hr = S_OK;
@@ -289,8 +587,9 @@ static HRESULT WINAPI ClientRpcChannelBuffer_SendReceive(LPRPCCHANNELBUFFER ifac
      * a thread to process the RPC when this function is called indirectly
      * from DllMain */
 
-    RpcBindingInqObject(msg->Handle, &ipid);
-    hr = ipid_get_dispatch_params(&ipid, &apt, &params->stub, &params->chan);
+    RpcBindingInqObject(message_state->binding_handle, &ipid);
+    hr = ipid_get_dispatch_params(&ipid, &apt, &params->stub, &params->chan,
+                                  &params->iid, &params->iface);
     params->handle = ClientRpcChannelBuffer_GetEventHandle(This);
     if ((hr == S_OK) && !apt->multi_threaded)
     {
@@ -337,6 +636,10 @@ static HRESULT WINAPI ClientRpcChannelBuffer_SendReceive(LPRPCCHANNELBUFFER ifac
     }
     ClientRpcChannelBuffer_ReleaseEventHandle(This, params->handle);
 
+    /* save away the message state again */
+    msg->Handle = message_state;
+    message_state->prefix_data_len = 0;
+
     if (hr == S_OK) hr = params->hr;
 
     status = params->status;
@@ -364,11 +667,21 @@ static HRESULT WINAPI ServerRpcChannelBuffer_FreeBuffer(LPRPCCHANNELBUFFER iface
 {
     RPC_MESSAGE *msg = (RPC_MESSAGE *)olemsg;
     RPC_STATUS status;
+    struct message_state *message_state;
 
     TRACE("(%p)\n", msg);
 
+    message_state = (struct message_state *)msg->Handle;
+    /* restore the binding handle and the real start of data */
+    msg->Handle = message_state->binding_handle;
+    msg->Buffer = (char *)msg->Buffer - message_state->prefix_data_len;
+    msg->BufferLength += message_state->prefix_data_len;
+    message_state->prefix_data_len = 0;
+
     status = I_RpcFreeBuffer(msg);
 
+    msg->Handle = message_state;
+
     TRACE("-- %ld\n", status);
 
     return HRESULT_FROM_WIN32(status);
@@ -378,13 +691,21 @@ static HRESULT WINAPI ClientRpcChannelBuffer_FreeBuffer(LPRPCCHANNELBUFFER iface
 {
     RPC_MESSAGE *msg = (RPC_MESSAGE *)olemsg;
     RPC_STATUS status;
+    struct message_state *message_state;
 
     TRACE("(%p)\n", msg);
 
+    message_state = (struct message_state *)msg->Handle;
+    /* restore the binding handle and the real start of data */
+    msg->Handle = message_state->binding_handle;
+    msg->Buffer = (char *)msg->Buffer - message_state->prefix_data_len;
+    msg->BufferLength += message_state->prefix_data_len;
+
     status = I_RpcFreeBuffer(msg);
 
     HeapFree(GetProcessHeap(), 0, msg->RpcInterfaceInformation);
     msg->RpcInterfaceInformation = NULL;
+    HeapFree(GetProcessHeap(), 0, message_state);
 
     TRACE("-- %ld\n", status);
 
@@ -519,11 +840,195 @@ HRESULT RPC_CreateServerChannel(IRpcChannelBuffer **chan)
     return S_OK;
 }
 
+/* unmarshals ORPCTHIS according to NDR rules, but doesn't allocate any memory */
+static HRESULT unmarshal_ORPCTHIS(RPC_MESSAGE *msg, ORPCTHIS *orpcthis,
+    ORPC_EXTENT_ARRAY *orpc_ext_array, WIRE_ORPC_EXTENT **first_wire_orpc_extent)
+{
+    const char *end = (char *)msg->Buffer + msg->BufferLength;
+
+    *first_wire_orpc_extent = NULL;
+
+    if (msg->BufferLength < FIELD_OFFSET(ORPCTHIS, extensions) + 4)
+    {
+        ERR("invalid buffer length\n");
+        return RPC_E_INVALID_HEADER;
+    }
+
+    memcpy(orpcthis, msg->Buffer, FIELD_OFFSET(ORPCTHIS, extensions));
+    msg->Buffer = (char *)msg->Buffer + FIELD_OFFSET(ORPCTHIS, extensions);
+
+    if ((const char *)msg->Buffer + sizeof(DWORD) > end)
+        return RPC_E_INVALID_HEADER;
+
+    if (*(DWORD *)msg->Buffer)
+        orpcthis->extensions = orpc_ext_array;
+    else
+        orpcthis->extensions = NULL;
+
+    msg->Buffer = (char *)msg->Buffer + sizeof(DWORD);
+
+    if (orpcthis->extensions)
+    {
+        DWORD pointer_id;
+        DWORD i;
+
+        memcpy(orpcthis->extensions, msg->Buffer, FIELD_OFFSET(ORPC_EXTENT_ARRAY, extent));
+        msg->Buffer = (char *)msg->Buffer + FIELD_OFFSET(ORPC_EXTENT_ARRAY, extent);
+
+        if ((const char *)msg->Buffer + 2 * sizeof(DWORD) > end)
+            return RPC_E_INVALID_HEADER;
+
+        pointer_id = *(DWORD *)msg->Buffer;
+        msg->Buffer = (char *)msg->Buffer + sizeof(DWORD);
+        orpcthis->extensions->extent = NULL;
+
+        if (pointer_id)
+        {
+            WIRE_ORPC_EXTENT *wire_orpc_extent;
+
+            /* conformance */
+            if (*(DWORD *)msg->Buffer != ((orpcthis->extensions->size+1)&~1))
+                return RPC_S_INVALID_BOUND;
+
+            msg->Buffer = (char *)msg->Buffer + sizeof(DWORD);
+
+            /* arbritary limit for security (don't know what native does) */
+            if (orpcthis->extensions->size > 256)
+            {
+                ERR("too many extensions: %ld\n", orpcthis->extensions->size);
+                return RPC_S_INVALID_BOUND;
+            }
+
+            *first_wire_orpc_extent = wire_orpc_extent = (WIRE_ORPC_EXTENT *)msg->Buffer;
+            for (i = 0; i < ((orpcthis->extensions->size+1)&~1); i++)
+            {
+                if ((const char *)&wire_orpc_extent->data[0] > end)
+                    return RPC_S_INVALID_BOUND;
+                if (wire_orpc_extent->conformance != ((wire_orpc_extent->size+7)&~7))
+                    return RPC_S_INVALID_BOUND;
+                if ((const char *)&wire_orpc_extent->data[wire_orpc_extent->conformance] > end)
+                    return RPC_S_INVALID_BOUND;
+                TRACE("size %u, guid %s\n", wire_orpc_extent->size, debugstr_guid(&wire_orpc_extent->id));
+                wire_orpc_extent = (WIRE_ORPC_EXTENT *)&wire_orpc_extent->data[wire_orpc_extent->conformance];
+            }
+            msg->Buffer = wire_orpc_extent;
+        }
+    }
+
+    if ((orpcthis->version.MajorVersion != COM_MAJOR_VERSION) ||
+        (orpcthis->version.MinorVersion > COM_MINOR_VERSION))
+    {
+        ERR("COM version {%d, %d} not supported\n",
+            orpcthis->version.MajorVersion, orpcthis->version.MinorVersion);
+        return RPC_E_VERSION_MISMATCH;
+    }
+
+    if (orpcthis->flags & ~(ORPCF_LOCAL|ORPCF_RESERVED1|ORPCF_RESERVED2|ORPCF_RESERVED3|ORPCF_RESERVED4))
+    {
+        ERR("invalid flags 0x%lx\n", orpcthis->flags & ~(ORPCF_LOCAL|ORPCF_RESERVED1|ORPCF_RESERVED2|ORPCF_RESERVED3|ORPCF_RESERVED4));
+        return RPC_E_INVALID_HEADER;
+    }
+
+    return S_OK;
+}
 
 void RPC_ExecuteCall(struct dispatch_params *params)
 {
-    params->hr = IRpcStubBuffer_Invoke(params->stub, params->msg, params->chan);
+    struct message_state *message_state = NULL;
+    RPC_MESSAGE *msg = (RPC_MESSAGE *)params->msg;
+    char *original_buffer = msg->Buffer;
+    ORPCTHIS orpcthis;
+    ORPC_EXTENT_ARRAY orpc_ext_array;
+    WIRE_ORPC_EXTENT *first_wire_orpc_extent;
+    GUID old_causality_id;
 
+    /* handle ORPCTHIS and server extensions */
+
+    params->hr = unmarshal_ORPCTHIS(msg, &orpcthis, &orpc_ext_array, &first_wire_orpc_extent);
+    if (params->hr != S_OK)
+        goto exit;
+
+    message_state = HeapAlloc(GetProcessHeap(), 0, sizeof(*message_state));
+    if (!message_state)
+    {
+        params->hr = E_OUTOFMEMORY;
+        goto exit;
+    }
+
+    message_state->prefix_data_len = original_buffer - (char *)msg->Buffer;
+    message_state->binding_handle = msg->Handle;
+
+    message_state->channel_hook_info.iid = params->iid;
+    message_state->channel_hook_info.cbSize = sizeof(message_state->channel_hook_info);
+    message_state->channel_hook_info.uCausality = orpcthis.cid;
+    message_state->channel_hook_info.dwServerPid = GetCurrentProcessId();
+    message_state->channel_hook_info.iMethod = msg->ProcNum;
+    message_state->channel_hook_info.pObject = params->iface;
+
+    if (orpcthis.extensions && first_wire_orpc_extent &&
+        orpcthis.extensions->size)
+        ChannelHooks_ServerNotify(&message_state->channel_hook_info, msg->DataRepresentation, first_wire_orpc_extent, orpcthis.extensions->size);
+
+    msg->Handle = message_state;
+    msg->BufferLength -= message_state->prefix_data_len;
+
+    /* call message filter */
+
+    if (COM_CurrentApt()->filter)
+    {
+        DWORD handlecall;
+        INTERFACEINFO interface_info;
+        CALLTYPE calltype;
+
+        interface_info.pUnk = params->iface;
+        interface_info.iid = params->iid;
+        interface_info.wMethod = msg->ProcNum;
+        if (IsEqualGUID(&orpcthis.cid, &COM_CurrentInfo()->causality_id))
+            calltype = CALLTYPE_NESTED;
+        else /* FIXME: also detect CALLTYPE_TOPLEVEL_CALLPENDING */
+            calltype = CALLTYPE_TOPLEVEL;
+        handlecall = IMessageFilter_HandleInComingCall(COM_CurrentApt()->filter,
+                                                       calltype,
+                                                       (HTASK)GetCurrentProcessId(),
+                                                       0 /* FIXME */,
+                                                       &interface_info);
+        TRACE("IMessageFilter_HandleInComingCall returned %d\n", handlecall);
+        switch (handlecall)
+        {
+        case SERVERCALL_REJECTED:
+            params->hr = RPC_E_CALL_REJECTED;
+            goto exit;
+        case SERVERCALL_RETRYLATER:
+#if 0 /* FIXME: handle retries on the client side before enabling this code */
+            params->hr = RPC_E_RETRY;
+            goto exit;
+#else
+            FIXME("retry call later not implemented\n");
+            break;
+#endif
+        case SERVERCALL_ISHANDLED:
+        default:
+            break;
+        }
+    }
+
+    /* invoke the method */
+
+    /* save the old causality ID - note: any calls executed while processing
+     * messages received during the SendReceive will appear to originate from
+     * this call - this should be checked with what Windows does */
+    old_causality_id = COM_CurrentInfo()->causality_id;
+    COM_CurrentInfo()->causality_id = orpcthis.cid;
+    params->hr = IRpcStubBuffer_Invoke(params->stub, params->msg, params->chan);
+    COM_CurrentInfo()->causality_id = old_causality_id;
+
+    message_state = (struct message_state *)msg->Handle;
+    msg->Handle = message_state->binding_handle;
+    msg->Buffer = (char *)msg->Buffer - message_state->prefix_data_len;
+    msg->BufferLength += message_state->prefix_data_len;
+
+exit:
+    HeapFree(GetProcessHeap(), 0, message_state);
     IRpcStubBuffer_Release(params->stub);
     IRpcChannelBuffer_Release(params->chan);
     if (params->handle) SetEvent(params->handle);
@@ -543,7 +1048,8 @@ static void __RPC_STUB dispatch_rpc(RPC_MESSAGE *msg)
     params = HeapAlloc(GetProcessHeap(), 0, sizeof(*params));
     if (!params) return RpcRaiseException(E_OUTOFMEMORY);
 
-    hr = ipid_get_dispatch_params(&ipid, &apt, &params->stub, &params->chan);
+    hr = ipid_get_dispatch_params(&ipid, &apt, &params->stub, &params->chan,
+                                  &params->iid, &params->iface);
     if (hr != S_OK)
     {
         ERR("no apartment found for ipid %s\n", debugstr_guid(&ipid));
