@@ -1290,13 +1290,12 @@ static void test_message_filter(void)
     ok_more_than_one_lock();
 
     hr = IClassFactory_CreateInstance(cf, NULL, &IID_IUnknown, (LPVOID*)&proxy);
-    todo_wine { ok(hr == RPC_E_CALL_REJECTED, "Call should have returned RPC_E_CALL_REJECTED, but return 0x%08x instead\n", hr); }
+    ok(hr == RPC_E_CALL_REJECTED, "Call should have returned RPC_E_CALL_REJECTED, but return 0x%08x instead\n", hr);
     if (proxy) IUnknown_Release(proxy);
     proxy = NULL;
 
     hr = CoRegisterMessageFilter(&MessageFilter, &prev_filter);
     ok_ole_success(hr, CoRegisterMessageFilter);
-    if (prev_filter) IMessageFilter_Release(prev_filter);
 
     hr = IClassFactory_CreateInstance(cf, NULL, &IID_IUnknown, (LPVOID*)&proxy);
     ok_ole_success(hr, IClassFactory_CreateInstance);
@@ -1308,6 +1307,9 @@ static void test_message_filter(void)
     ok_no_locks();
 
     end_host_object(tid, thread);
+
+    hr = CoRegisterMessageFilter(prev_filter, NULL);
+    ok_ole_success(hr, CoRegisterMessageFilter);
 }
 
 /* test failure case of trying to unmarshal from bad stream */
@@ -1456,9 +1458,11 @@ static void test_proxybuffer(REFIID riid)
     ok(refs == 1, "Ref count of outer unknown should have been 1 instead of %d\n", refs);
 
     refs = IPSFactoryBuffer_Release(psfb);
-#if 0 /* not reliable on native. maybe it leaks references! */
-    ok(refs == 0, "Ref-count leak of %ld on IPSFactoryBuffer\n", refs);
-#endif
+    if (0)
+    {
+    /* not reliable on native. maybe it leaks references! */
+    ok(refs == 0, "Ref-count leak of %d on IPSFactoryBuffer\n", refs);
+    }
 
     refs = IUnknown_Release((IUnknown *)lpvtbl);
     ok(refs == 0, "Ref-count leak of %d on IRpcProxyBuffer\n", refs);
@@ -1487,9 +1491,11 @@ static void test_stubbuffer(REFIID riid)
     ok_ole_success(hr, IPSFactoryBuffer_CreateStub);
 
     refs = IPSFactoryBuffer_Release(psfb);
-#if 0 /* not reliable on native. maybe it leaks references */
-    ok(refs == 0, "Ref-count leak of %ld on IPSFactoryBuffer\n", refs);
-#endif
+    if (0)
+    {
+    /* not reliable on native. maybe it leaks references */
+    ok(refs == 0, "Ref-count leak of %d on IPSFactoryBuffer\n", refs);
+    }
 
     ok_more_than_one_lock();
 
@@ -1732,11 +1738,12 @@ static void test_freethreadedmarshaler(void)
 
 /* native doesn't allow us to unmarshal or release the stream data,
  * presumably because it wants us to call CoMarshalInterface instead */
-#if 0
+    if (0)
+    {
     /* local normal marshaling */
 
     IStream_Seek(pStream, llZero, STREAM_SEEK_SET, NULL);
-    hr = IMarshal_MarshalInterface(pFTMarshal, pStream, IID_IClassFactory, (IUnknown*)&Test_ClassFactory, MSHCTX_LOCAL, NULL, MSHLFLAGS_NORMAL);
+    hr = IMarshal_MarshalInterface(pFTMarshal, pStream, &IID_IClassFactory, (IUnknown*)&Test_ClassFactory, MSHCTX_LOCAL, NULL, MSHLFLAGS_NORMAL);
     ok_ole_success(hr, IMarshal_MarshalInterface);
 
     ok_more_than_one_lock();
@@ -1748,7 +1755,7 @@ static void test_freethreadedmarshaler(void)
     ok_ole_success(hr, IMarshal_ReleaseMarshalData);
 
     ok_no_locks();
-#endif
+    }
 
     /* inproc table-strong marshaling */
 
@@ -2069,190 +2076,6 @@ static void test_globalinterfacetable(void)
 	CloseHandle(thread);
 }
 
-static const char cf_marshaled[] =
-{
-    0x9, 0x0, 0x0, 0x0,
-    0x0, 0x0, 0x0, 0x0,
-    0x9, 0x0, 0x0, 0x0,
-    'M', 0x0, 'y', 0x0,
-    'F', 0x0, 'o', 0x0,
-    'r', 0x0, 'm', 0x0,
-    'a', 0x0, 't', 0x0,
-    0x0, 0x0
-};
-
-static void test_marshal_CLIPFORMAT(void)
-{
-    unsigned char *buffer;
-    ULONG size;
-    ULONG flags = MAKELONG(MSHCTX_DIFFERENTMACHINE, NDR_LOCAL_DATA_REPRESENTATION);
-    wireCLIPFORMAT wirecf;
-    CLIPFORMAT cf = RegisterClipboardFormatA("MyFormat");
-    CLIPFORMAT cf2;
-
-    size = CLIPFORMAT_UserSize(&flags, 0, &cf);
-    ok(size == sizeof(*wirecf) + sizeof(cf_marshaled), "Wrong size %d\n", size);
-
-    buffer = HeapAlloc(GetProcessHeap(), 0, size);
-    CLIPFORMAT_UserMarshal(&flags, buffer, &cf);
-    wirecf = (wireCLIPFORMAT)buffer;
-    ok(wirecf->fContext == WDT_REMOTE_CALL, "Context should be WDT_REMOTE_CALL instead of 0x%08lx\n", wirecf->fContext);
-    ok(wirecf->u.dwValue == cf, "Marshaled value should be 0x%04x instead of 0x%04x\n", cf, wirecf->u.dwValue);
-    ok(!memcmp(wirecf+1, cf_marshaled, sizeof(cf_marshaled)), "Marshaled data differs\n");
-
-    CLIPFORMAT_UserUnmarshal(&flags, buffer, &cf2);
-    ok(cf == cf2, "Didn't unmarshal properly\n");
-    HeapFree(GetProcessHeap(), 0, buffer);
-
-    CLIPFORMAT_UserFree(&flags, &cf2);
-}
-
-static void test_marshal_HWND(void)
-{
-    unsigned char *buffer;
-    ULONG size;
-    ULONG flags = MAKELONG(MSHCTX_LOCAL, NDR_LOCAL_DATA_REPRESENTATION);
-    HWND hwnd = GetDesktopWindow();
-    HWND hwnd2;
-    wireHWND wirehwnd;
-
-    size = HWND_UserSize(&flags, 0, &hwnd);
-    ok(size == sizeof(*wirehwnd), "Wrong size %d\n", size);
-
-    buffer = HeapAlloc(GetProcessHeap(), 0, size);
-    HWND_UserMarshal(&flags, buffer, &hwnd);
-    wirehwnd = (wireHWND)buffer;
-    ok(wirehwnd->fContext == WDT_INPROC_CALL, "Context should be WDT_INPROC_CALL instead of 0x%08lx\n", wirehwnd->fContext);
-    ok(wirehwnd->u.hInproc == (LONG_PTR)hwnd, "Marshaled value should be %p instead of %p\n", hwnd, (HANDLE)wirehwnd->u.hRemote);
-
-    HWND_UserUnmarshal(&flags, buffer, &hwnd2);
-    ok(hwnd == hwnd2, "Didn't unmarshal properly\n");
-    HeapFree(GetProcessHeap(), 0, buffer);
-
-    HWND_UserFree(&flags, &hwnd2);
-}
-
-static void test_marshal_HGLOBAL(void)
-{
-    unsigned char *buffer;
-    ULONG size;
-    ULONG flags = MAKELONG(MSHCTX_LOCAL, NDR_LOCAL_DATA_REPRESENTATION);
-    HGLOBAL hglobal;
-    HGLOBAL hglobal2;
-    unsigned char *wirehglobal;
-    int i;
-
-    hglobal = NULL;
-    flags = MAKELONG(MSHCTX_LOCAL, NDR_LOCAL_DATA_REPRESENTATION);
-    size = HGLOBAL_UserSize(&flags, 0, &hglobal);
-    /* native is poorly programmed and allocates 4 bytes more than it needs to
-     * here - Wine doesn't have to emulate that */
-    ok((size == 8) || (size == 12), "Size should be 12, instead of %d\n", size);
-    buffer = HeapAlloc(GetProcessHeap(), 0, size);
-    HGLOBAL_UserMarshal(&flags, buffer, &hglobal);
-    wirehglobal = buffer;
-    ok(*(ULONG *)wirehglobal == WDT_REMOTE_CALL, "Context should be WDT_REMOTE_CALL instead of 0x%08x\n", *(ULONG *)wirehglobal);
-    wirehglobal += sizeof(ULONG);
-    ok(*(ULONG *)wirehglobal == (ULONG)hglobal, "buffer+4 should be HGLOBAL\n");
-    HGLOBAL_UserUnmarshal(&flags, buffer, &hglobal2);
-    ok(hglobal2 == hglobal, "Didn't unmarshal properly\n");
-    HeapFree(GetProcessHeap(), 0, buffer);
-    HGLOBAL_UserFree(&flags, &hglobal2);
-
-    hglobal = GlobalAlloc(0, 4);
-    buffer = GlobalLock(hglobal);
-    for (i = 0; i < 4; i++)
-        buffer[i] = i;
-    GlobalUnlock(hglobal);
-    flags = MAKELONG(MSHCTX_LOCAL, NDR_LOCAL_DATA_REPRESENTATION);
-    size = HGLOBAL_UserSize(&flags, 0, &hglobal);
-    /* native is poorly programmed and allocates 4 bytes more than it needs to
-     * here - Wine doesn't have to emulate that */
-    ok((size == 24) || (size == 28), "Size should be 24 or 28, instead of %d\n", size);
-    buffer = HeapAlloc(GetProcessHeap(), 0, size);
-    HGLOBAL_UserMarshal(&flags, buffer, &hglobal);
-    wirehglobal = buffer;
-    ok(*(ULONG *)wirehglobal == WDT_REMOTE_CALL, "Context should be WDT_REMOTE_CALL instead of 0x%08x\n", *(ULONG *)wirehglobal);
-    wirehglobal += sizeof(ULONG);
-    ok(*(ULONG *)wirehglobal == (ULONG)hglobal, "buffer+0x4 should be HGLOBAL\n");
-    wirehglobal += sizeof(ULONG);
-    ok(*(ULONG *)wirehglobal == 4, "buffer+0x8 should be size of HGLOBAL\n");
-    wirehglobal += sizeof(ULONG);
-    ok(*(ULONG *)wirehglobal == (ULONG)hglobal, "buffer+0xc should be HGLOBAL\n");
-    wirehglobal += sizeof(ULONG);
-    ok(*(ULONG *)wirehglobal == 4, "buffer+0x10 should be size of HGLOBAL\n");
-    wirehglobal += sizeof(ULONG);
-    for (i = 0; i < 4; i++)
-        ok(wirehglobal[i] == i, "buffer+0x%x should be %d\n", 0x10 + i, i);
-    HGLOBAL_UserUnmarshal(&flags, buffer, &hglobal2);
-    ok(hglobal2 != NULL, "Didn't unmarshal properly\n");
-    HeapFree(GetProcessHeap(), 0, buffer);
-    HGLOBAL_UserFree(&flags, &hglobal2);
-    GlobalFree(hglobal);
-}
-
-static HENHMETAFILE create_emf(void)
-{
-    RECT rect = {0, 0, 100, 100};
-    HDC hdc = CreateEnhMetaFile(NULL, NULL, &rect, "HENHMETAFILE Marshaling Test\0Test\0\0");
-    ExtTextOut(hdc, 0, 0, ETO_OPAQUE, NULL, "Test String", strlen("Test String"), NULL);
-    return CloseEnhMetaFile(hdc);
-}
-
-static void test_marshal_HENHMETAFILE(void)
-{
-    unsigned char *buffer;
-    ULONG size;
-    ULONG flags = MAKELONG(MSHCTX_DIFFERENTMACHINE, NDR_LOCAL_DATA_REPRESENTATION);
-    HENHMETAFILE hemf;
-    HENHMETAFILE hemf2 = NULL;
-    unsigned char *wirehemf;
-
-    hemf = create_emf();
-
-    size = HENHMETAFILE_UserSize(&flags, 0, &hemf);
-    ok(size > 20, "size should be at least 20 bytes, not %d\n", size);
-    buffer = HeapAlloc(GetProcessHeap(), 0, size);
-    HENHMETAFILE_UserMarshal(&flags, buffer, &hemf);
-    wirehemf = buffer;
-    ok(*(DWORD *)wirehemf == WDT_REMOTE_CALL, "wirestgm + 0x0 should be WDT_REMOTE_CALL instead of 0x%08x\n", *(DWORD *)wirehemf);
-    wirehemf += sizeof(DWORD);
-    ok(*(DWORD *)wirehemf == (DWORD)(DWORD_PTR)hemf, "wirestgm + 0x4 should be hemf instead of 0x%08x\n", *(DWORD *)wirehemf);
-    wirehemf += sizeof(DWORD);
-    ok(*(DWORD *)wirehemf == (size - 0x10), "wirestgm + 0x8 should be size - 0x10 instead of 0x%08x\n", *(DWORD *)wirehemf);
-    wirehemf += sizeof(DWORD);
-    ok(*(DWORD *)wirehemf == (size - 0x10), "wirestgm + 0xc should be size - 0x10 instead of 0x%08x\n", *(DWORD *)wirehemf);
-    wirehemf += sizeof(DWORD);
-    ok(*(DWORD *)wirehemf == EMR_HEADER, "wirestgm + 0x10 should be EMR_HEADER instead of %d\n", *(DWORD *)wirehemf);
-    wirehemf += sizeof(DWORD);
-    /* ... rest of data not tested - refer to tests for GetEnhMetaFileBits
-     * at this point */
-
-    HENHMETAFILE_UserUnmarshal(&flags, buffer, &hemf2);
-    ok(hemf2 != NULL, "HENHMETAFILE didn't unmarshal\n");
-    HeapFree(GetProcessHeap(), 0, buffer);
-    HENHMETAFILE_UserFree(&flags, &hemf2);
-    DeleteEnhMetaFile(hemf);
-
-    /* test NULL emf */
-    hemf = NULL;
-
-    size = HENHMETAFILE_UserSize(&flags, 0, &hemf);
-    ok(size == 8, "size should be 8 bytes, not %d\n", size);
-    buffer = (unsigned char *)HeapAlloc(GetProcessHeap(), 0, size);
-    HENHMETAFILE_UserMarshal(&flags, buffer, &hemf);
-    wirehemf = buffer;
-    ok(*(DWORD *)wirehemf == WDT_REMOTE_CALL, "wirestgm + 0x0 should be WDT_REMOTE_CALL instead of 0x%08x\n", *(DWORD *)wirehemf);
-    wirehemf += sizeof(DWORD);
-    ok(*(DWORD *)wirehemf == (DWORD)(DWORD_PTR)hemf, "wirestgm + 0x4 should be hemf instead of 0x%08x\n", *(DWORD *)wirehemf);
-    wirehemf += sizeof(DWORD);
-
-    HENHMETAFILE_UserUnmarshal(&flags, buffer, &hemf2);
-    ok(hemf2 == NULL, "NULL HENHMETAFILE didn't unmarshal\n");
-    HeapFree(GetProcessHeap(), 0, buffer);
-    HENHMETAFILE_UserFree(&flags, &hemf2);
-}
-
 static void test_CoGetInterfaceAndReleaseStream(void)
 {
     HRESULT hr;
@@ -2317,11 +2140,6 @@ START_TEST(marshal)
     test_ROT();
     test_globalinterfacetable();
 
-    test_marshal_CLIPFORMAT();
-    test_marshal_HWND();
-    test_marshal_HGLOBAL();
-    test_marshal_HENHMETAFILE();
-
     test_CoGetInterfaceAndReleaseStream();
 
     CoUninitialize();
