@@ -250,19 +250,13 @@ static HWND get_notif_hwnd(void)
         wndclass.hInstance = URLMON_hInstance;
 
         wnd_class = RegisterClassExW(&wndclass);
+        if (!wnd_class && GetLastError() == ERROR_CLASS_ALREADY_EXISTS)
+            wnd_class = 1;
     }
 
-    if(!urlmon_tls)
-        urlmon_tls = TlsAlloc();
-
-    hwnd = TlsGetValue(urlmon_tls);
-    if(hwnd)
-        return hwnd;
-
-    hwnd = CreateWindowExW(0, MAKEINTATOMW(wnd_class),
+    hwnd = CreateWindowExW(0, wszURLMonikerNotificationWindow,
                            wszURLMonikerNotificationWindow, 0, 0, 0, 0, 0, HWND_MESSAGE,
                            NULL, URLMON_hInstance, NULL);
-    TlsSetValue(urlmon_tls, hwnd);
 
     TRACE("hwnd = %p\n", hwnd);
 
@@ -306,13 +300,13 @@ static void on_progress(Binding *This, ULONG progress, ULONG progress_max,
 
 static void dump_BINDINFO(BINDINFO *bi)
 {
-    static const char *BINDINFOF_str[] = {
+    static const char * const BINDINFOF_str[] = {
         "#0",
         "BINDINFOF_URLENCODESTGMEDDATA",
         "BINDINFOF_URLENCODEDEXTRAINFO"
     };
 
-    static const char *BINDVERB_str[] = {
+    static const char * const BINDVERB_str[] = {
         "BINDVERB_GET",
         "BINDVERB_POST",
         "BINDVERB_PUT",
@@ -691,6 +685,8 @@ static ULONG WINAPI Binding_Release(IBinding *iface)
     TRACE("(%p) ref=%d\n", This, ref);
 
     if(!ref) {
+        if (This->notif_hwnd)
+            DestroyWindow( This->notif_hwnd );
         if(This->callback)
             IBindStatusCallback_Release(This->callback);
         if(This->protocol)
