@@ -46,7 +46,8 @@ static void test_ScriptItemIzeShapePlace(HDC hdc, unsigned short pwOutGlyphs[256
     WCHAR           TestItem1[] = {'T', 'e', 's', 't', 'a', 0}; 
     WCHAR           TestItem2[] = {'T', 'e', 's', 't', 'b', 0}; 
     WCHAR           TestItem3[] = {'T', 'e', 's', 't', 'c',' ','1','2','3',' ',' ','e','n','d',0}; 
-    WCHAR           TestItem4[] = {'T', 'e', 's', 't', 'c',' ',0x0684,0x0694,0x06a4,' ',' ','e','n','d',0}; 
+    WCHAR           TestItem4[] = {'T', 'e', 's', 't', 'c',' ',0x0684,0x0694,0x06a4,' ',' ','e','n','d',0};
+    WCHAR           TestItem5[] = {0x0684,'T','e','s','t','c',' ',0x0684,0x0694,0x06a4,' ',' ','e','n','d',0}; 
 
     SCRIPT_CACHE    psc;
     int             cChars;
@@ -243,9 +244,19 @@ static void test_ScriptItemIzeShapePlace(HDC hdc, unsigned short pwOutGlyphs[256
         hr = ScriptFreeCache( &psc);
         ok (!psc, "psc is not null after ScriptFreeCache\n");
     }
+
+    /*
+     * This test is for when the first unicode character requires bidi support
+     */ 
+    cInChars = (sizeof(TestItem5)-1)/sizeof(WCHAR);
+    hr = ScriptItemize(TestItem5, cInChars, cMaxItems, NULL, NULL, pItem, &pcItems);
+    ok (hr == 0, "ScriptItemize should return 0, returned %08x\n", hr);
+    ok (pcItems == 4, "There should have been 4 items, found %d\n", pcItems);
+    ok (pItem[0].a.s.uBidiLevel == 1, "The first character should have been bidi=1 not %d\n", 
+                                       pItem[0].a.s.uBidiLevel);
 }
 
-void test_ScriptGetCMap(HDC hdc, unsigned short pwOutGlyphs[256])
+static void test_ScriptGetCMap(HDC hdc, unsigned short pwOutGlyphs[256])
 {
     HRESULT         hr;
     SCRIPT_CACHE    psc = NULL;
@@ -301,7 +312,7 @@ void test_ScriptGetCMap(HDC hdc, unsigned short pwOutGlyphs[256])
 
 }
 
-void test_ScriptGetFontProperties(void)
+static void test_ScriptGetFontProperties(void)
 {
     HRESULT         hr;
     HDC             hdc;
@@ -377,7 +388,7 @@ void test_ScriptGetFontProperties(void)
     DestroyWindow(hwnd);
 }
 
-void test_ScriptTextOut(void)
+static void test_ScriptTextOut(void)
 {
     HRESULT         hr;
     HWND            hwnd;
@@ -563,6 +574,25 @@ static void test_ScriptXtoX(void)
     ok(hr == S_OK, "ScriptXtoCP should return S_OK not %08x\n", hr);
     ok(piCP == 4, "iX=%d should return piCP=4 not %d\n", iX, piCP);
 
+    iX = 0;
+    cChars = 10;
+    cGlyphs = 10;
+    hr = ScriptXtoCP(iX, cChars, cGlyphs, pwLogClust, psva, piAdvance, &psa, &piCP, &piTrailing);
+    ok(hr == S_OK, "ScriptXtoCP should return S_OK not %08x\n", hr);
+    ok(piCP == 0, "iX=%d should return piCP=0 not %d\n", iX, piCP);
+    iX = 195;
+    cChars = 10;
+    cGlyphs = 10;
+    hr = ScriptXtoCP(iX, cChars, cGlyphs, pwLogClust, psva, piAdvance, &psa, &piCP, &piTrailing);
+    ok(hr == S_OK, "ScriptXtoCP should return S_OK not %08x\n", hr);
+    ok(piCP == 0, "iX=%d should return piCP=0 not %d\n", iX, piCP);
+    iX = 196;
+    cChars = 10;
+    cGlyphs = 10;
+    hr = ScriptXtoCP(iX, cChars, cGlyphs, pwLogClust, psva, piAdvance, &psa, &piCP, &piTrailing);
+    ok(hr == S_OK, "ScriptXtoCP should return S_OK not %08x\n", hr);
+    ok(piCP == 1, "iX=%d should return piCP=1 not %d\n", iX, piCP);
+
     iCP=5;
     fTrailing = FALSE;
     cChars = 10;
@@ -603,30 +633,38 @@ static void test_ScriptXtoX(void)
 
 static void test_ScriptString(void)
 {
+/*******************************************************************************************
+ *
+ * This set of tests are for the string functions of uniscribe.  The ScriptStringAnalyse
+ * function allocates memory pointed to by the SCRIPT_STRING_ANALYSIS ssa pointer.  This 
+ * memory if freed by ScriptStringFree.  There needs to be a valid hdc for this this as 
+ * ScriptStrinAnalyse calls ScriptSItemize, ScriptShape and ScriptPlace which require it.
+ *
+ */
+
     HRESULT         hr;
     HWND            hwnd;
     HDC             hdc = 0;
-    WCHAR           teststr[] = {'T', 'e', 's', 't', 'a', '\0'};
-    void            *pString = (WCHAR *) &teststr;
-    int             cString = 5;
-    int             cGlyphs = cString * 2 + 16;
-    int             iCharset = -1;
-    DWORD           dwFlags = SSA_GLYPHS;
-    int             iReqWidth = 100;
-    SCRIPT_CONTROL  psControl;
-    SCRIPT_STATE    psState;
-    const int       piDx[5] = {10, 10, 10, 10, 10};
-    SCRIPT_TABDEF   pTabdef;
-    const BYTE      pbInClass = 0;
-    SCRIPT_STRING_ANALYSIS pssa = NULL;
+    WCHAR           teststr[] = {'T','e','s','t','1',' ','a','2','b','3', '\0'};
+    int             String = (sizeof(teststr)/sizeof(WCHAR))-1;
+    int             Glyphs = String * 2 + 16;
+    int             Charset;
+    DWORD           Flags = SSA_GLYPHS;
+    int             ReqWidth = 100;
+    SCRIPT_CONTROL  Control;
+    SCRIPT_STATE    State;
+    const int       Dx[5] = {10, 10, 10, 10, 10};
+    SCRIPT_TABDEF   Tabdef;
+    const BYTE      InClass = 0;
+    SCRIPT_STRING_ANALYSIS ssa = NULL;
 
-    int             iX = 10; 
-    int             iY = 100;
-    UINT            uOptions = 0; 
-    const RECT      prc = {0, 50, 100, 100}; 
-    int             iMinSel = 0; 
-    int             iMaxSel = 0;
-    BOOL            fDisabled = FALSE;
+    int             X = 10; 
+    int             Y = 100;
+    UINT            Options = 0; 
+    const RECT      rc = {0, 50, 100, 100}; 
+    int             MinSel = 0; 
+    int             MaxSel = 0;
+    BOOL            Disabled = FALSE;
 
     LOGFONTA        lf;
     HFONT           zfont;
@@ -647,35 +685,215 @@ static void test_ScriptString(void)
     lf.lfOrientation = 0;
     lf.lfUnderline = 0;
     lf.lfStrikeOut = 0;
-    lf.lfWeight = 3;
+    lf.lfWeight = 300;
     lf.lfWidth = 10;
 
     zfont = (HFONT) SelectObject(hdc, CreateFontIndirectA(&lf));
  
+    Charset = -1;     /* this flag indicates unicode input */
     /* Test without hdc to get E_INVALIDARG */
-    hr = ScriptStringAnalyse( NULL, pString, cString, cGlyphs, iCharset, dwFlags,
-                             iReqWidth, &psControl, &psState, piDx, &pTabdef,
-                             &pbInClass, &pssa);
+    hr = ScriptStringAnalyse( NULL, teststr, String, Glyphs, Charset, Flags,
+                             ReqWidth, &Control, &State, Dx, &Tabdef,
+                             &InClass, &ssa);
     ok(hr == E_PENDING, "ScriptStringAnalyse Stub should return E_PENDING not %08x\n", hr);
 
     /* test with hdc, this should be a valid test  */
-    hr = ScriptStringAnalyse( hdc, pString, cString, cGlyphs, iCharset, dwFlags,
-                              iReqWidth, &psControl, &psState, piDx, &pTabdef,
-                              &pbInClass, &pssa);
-    ok(hr == E_NOTIMPL, "ScriptStringAnalyse Stub should return E_NOTIMPL not %08x\n", hr);
-/*    Commented code it pending new code in ScriptStringAnalysis */
-/*    ok(hr == S_OK, "ScriptStringAnalyse Stub should return S_OK not %08x\n", (unsigned int) hr);*/
-/*    ok(pssa != NULL, "ScriptStringAnalyse pssa should not be NULL\n");*/
+    hr = ScriptStringAnalyse( hdc, teststr, String, Glyphs, Charset, Flags,
+                              ReqWidth, &Control, &State, Dx, &Tabdef,
+                              &InClass, &ssa);
+    ok(hr == S_OK, "ScriptStringAnalyse should return S_OK not %08x\n", hr);
+
+    /* test makes sure that a call with a valid pssa still works */
+    hr = ScriptStringAnalyse( hdc, teststr, String, Glyphs, Charset, Flags,
+                              ReqWidth, &Control, &State, Dx, &Tabdef,
+                              &InClass, &ssa);
+    ok(hr == S_OK, "ScriptStringAnalyse should return S_OK not %08x\n", hr);
+    ok(ssa != NULL, "ScriptStringAnalyse pssa should not be NULL\n");
+
     if  (hr == 0)
     {
-        hr = ScriptStringOut(pssa, iX, iY, uOptions, &prc, iMinSel, iMaxSel,fDisabled);
-        ok(hr == E_NOTIMPL, "ScriptStringOut Stub should return E_NOTIMPL not %08x\n", hr);
-        hr = ScriptStringFree(&pssa);
-        ok(hr == S_OK, "ScriptStringFree Stub should return S_OK not %08x\n", hr);
+        hr = ScriptStringOut(ssa, X, Y, Options, &rc, MinSel, MaxSel, Disabled);
+        todo_wine ok(hr == S_OK, "ScriptStringOut should return S_OK not %08x\n", hr);
+        hr = ScriptStringFree(&ssa);
+        ok(hr == S_OK, "ScriptStringFree should return S_OK not %08x\n", hr);
     }
 }
 
-void test_ScriptCacheGetHeight(HDC hdc)
+static void test_ScriptStringXtoCP_CPtoX(HDC hdc)
+{
+/*****************************************************************************************
+ *
+ * This test is for the ScriptStringXtoCP and ScriptStringXtoCP functions.  Due to the
+ * nature of the fonts between Windows and Wine, the test is implemented by generating
+ * values using one one function then checking the output of the second.  In this way
+ * the validity of the functions is established using Windows as a base and confirming
+ * similar behaviour in wine.
+ */
+
+    HRESULT         hr;
+    WCHAR           teststr1[] = {'T', 'e', 's', 't', 'e', '1', '2', ' ', 'a', '\0'};
+    void            *String = (WCHAR *) &teststr1;      /* ScriptStringAnalysis needs void */
+    int             String_len = (sizeof(teststr1)/sizeof(WCHAR))-1;
+    int             Glyphs = String_len * 2 + 16;       /* size of buffer as recommended  */
+    int             Charset = -1;                       /* unicode                        */
+    DWORD           Flags = SSA_GLYPHS;
+    int             ReqWidth = 100;
+    SCRIPT_CONTROL  Control;
+    SCRIPT_STATE    State;
+    SCRIPT_TABDEF   Tabdef;
+    const BYTE      InClass = 0;
+    SCRIPT_STRING_ANALYSIS ssa = NULL;
+
+    int             Ch;                                  /* Character position in string */
+    int             iTrailing;
+    int             Cp;                                  /* Character position in string */
+    int             X;
+    BOOL            fTrailing;
+
+    LOGFONTA        lf;
+    HFONT           zfont;
+
+    lstrcpyA(lf.lfFaceName, "Symbol");
+    lf.lfHeight = 10;
+    lf.lfCharSet = 0;
+    lf.lfItalic = 0;
+    lf.lfEscapement = 0;
+    lf.lfOrientation = 0;
+    lf.lfUnderline = 0;
+    lf.lfStrikeOut = 0;
+    lf.lfWeight = 400;
+    lf.lfWidth = 0;
+    lf.lfPitchAndFamily = 0;
+
+    zfont = (HFONT) SelectObject(hdc, CreateFontIndirectA(&lf));
+
+    /* Test with hdc, this should be a valid test
+     * Here we generrate an SCRIPT_STRING_ANALYSIS that will be used as input to the
+     * following character positions to X and X to character position functions.
+     */
+    hr = ScriptStringAnalyse( hdc, String, String_len, Glyphs, Charset, Flags,
+                              ReqWidth, &Control, &State, NULL, &Tabdef,
+                              &InClass, &ssa);
+    ok(hr == S_OK, "ScriptStringAnalyse should return S_OK not %08x\n", hr);
+    ok(ssa != NULL, "ScriptStringAnalyse ssa should not be NULL\n");
+    if  (hr == 0)
+    {
+        /*
+         * Loop to generate character positions to provide starting positions for the
+         * ScriptStringCPtoX and ScriptStringXtoCP functions
+         */
+        for (Cp = 0; Cp < String_len; Cp++)
+        {
+            /* The fTrailing flag is used to indicate whether the X being returned is at
+             * the beginning or the end of the character. What happens here is that if
+             * fTrailing indicates the end of the character, ie. FALSE, then ScriptStringXtoCP
+             * returns the beginning of the next character and iTrailing is FALSE.  So for this
+             * loop iTrailing will be FALSE in both cases.
+             */
+            fTrailing = FALSE;
+            hr = ScriptStringCPtoX(ssa, Cp, fTrailing, &X);
+            ok(hr == S_OK, "ScriptStringCPtoX should return S_OK not %08x\n", hr);
+            hr = ScriptStringXtoCP(ssa, X, &Ch, &iTrailing);
+            ok(hr == S_OK, "ScriptStringXtoCP should return S_OK not %08x\n", hr);
+            ok(Cp == Ch, "ScriptStringXtoCP should return Ch = %d not %d for X = %d\n", Cp, Ch, X);
+            ok(iTrailing == FALSE, "ScriptStringXtoCP should return iTrailing = 0 not %d for X = %d\n", 
+                                  iTrailing, X);
+            fTrailing = TRUE;
+            hr = ScriptStringCPtoX(ssa, Cp, fTrailing, &X);
+            ok(hr == S_OK, "ScriptStringCPtoX should return S_OK not %08x\n", hr);
+            hr = ScriptStringXtoCP(ssa, X, &Ch, &iTrailing);
+            ok(hr == S_OK, "ScriptStringXtoCP should return S_OK not %08x\n", hr);
+
+            /*
+             * Check that character position returned by ScriptStringXtoCP in Ch matches the
+             * one input to ScriptStringCPtoX.  This means that the Cp to X position and back
+             * again works
+             */
+            ok(Cp + 1 == Ch, "ScriptStringXtoCP should return Ch = %d not %d for X = %d\n", Cp + 1, Ch, X);
+            ok(iTrailing == FALSE, "ScriptStringXtoCP should return iTrailing = 0 not %d for X = %d\n", 
+                                   iTrailing, X);
+        }
+        /*
+         * This test is to check that if the X position is just inside the trailing edge of the
+         * character then iTrailing will indicate the trailing edge, ie. TRUE
+         */
+        fTrailing = TRUE;
+        Cp = 3;
+        hr = ScriptStringCPtoX(ssa, Cp, fTrailing, &X);
+        ok(hr == S_OK, "ScriptStringCPtoX should return S_OK not %08x\n", hr);
+        X--;                                /* put X just inside the trailing edge */
+        hr = ScriptStringXtoCP(ssa, X, &Ch, &iTrailing);
+        ok(hr == S_OK, "ScriptStringXtoCP should return S_OK not %08x\n", hr);
+        ok(Cp == Ch, "ScriptStringXtoCP should return Ch = %d not %d for X = %d\n", Cp, Ch, X);
+        ok(iTrailing == TRUE, "ScriptStringXtoCP should return iTrailing = 1 not %d for X = %d\n", 
+                                  iTrailing, X);
+
+        /*
+         * This test is to check that if the X position is just outside the trailing edge of the
+         * character then iTrailing will indicate the leading edge, ie. FALSE, and Ch will indicate
+         * the next character, ie. Cp + 1 
+         */
+        fTrailing = TRUE;
+        Cp = 3;
+        hr = ScriptStringCPtoX(ssa, Cp, fTrailing, &X);
+        ok(hr == S_OK, "ScriptStringCPtoX should return S_OK not %08x\n", hr);
+        X++;                                /* put X just outside the trailing edge */
+        hr = ScriptStringXtoCP(ssa, X, &Ch, &iTrailing);
+        ok(hr == S_OK, "ScriptStringXtoCP should return S_OK not %08x\n", hr);
+        ok(Cp + 1 == Ch, "ScriptStringXtoCP should return Ch = %d not %d for X = %d\n", Cp + 1, Ch, X);
+        ok(iTrailing == FALSE, "ScriptStringXtoCP should return iTrailing = 0 not %d for X = %d\n", 
+                                  iTrailing, X);
+
+        /*
+         * This test is to check that if the X position is just outside the leading edge of the
+         * character then iTrailing will indicate the trailing edge, ie. TRUE, and Ch will indicate
+         * the next character down , ie. Cp - 1 
+         */
+        fTrailing = FALSE;
+        Cp = 3;
+        hr = ScriptStringCPtoX(ssa, Cp, fTrailing, &X);
+        ok(hr == S_OK, "ScriptStringCPtoX should return S_OK not %08x\n", hr);
+        X--;                                /* put X just outside the leading edge */
+        hr = ScriptStringXtoCP(ssa, X, &Ch, &iTrailing);
+        ok(hr == S_OK, "ScriptStringXtoCP should return S_OK not %08x\n", hr);
+        ok(Cp - 1 == Ch, "ScriptStringXtoCP should return Ch = %d not %d for X = %d\n", Cp - 1, Ch, X);
+        ok(iTrailing == TRUE, "ScriptStringXtoCP should return iTrailing = 1 not %d for X = %d\n", 
+                                  iTrailing, X);
+
+        /*
+         * Cleanup the the SSA for the next round of tests
+         */
+        hr = ScriptStringFree(&ssa);
+        ok(hr == S_OK, "ScriptStringFree should return S_OK not %08x\n", hr);
+
+        /*
+         * Test to see that exceeding the number of chars returns E_INVALIDARG.  First
+         * generate an SSA for the subsequent tests.
+         */
+        hr = ScriptStringAnalyse( hdc, String, String_len, Glyphs, Charset, Flags,
+                                  ReqWidth, &Control, &State, NULL, &Tabdef,
+                                  &InClass, &ssa);
+        ok(hr == S_OK, "ScriptStringAnalyse should return S_OK not %08x\n", hr);
+
+        /*
+         * When ScriptStringCPtoX is called with a character position Cp that exceeds the
+         * string length, return E_INVALIDARG.  This also invalidates the ssa so a 
+         * ScriptStringFree should also fail.
+         */
+        fTrailing = FALSE;
+        Cp = String_len + 1; 
+        hr = ScriptStringCPtoX(ssa, Cp, fTrailing, &X);
+        ok(hr == E_INVALIDARG, "ScriptStringCPtoX should return E_INVALIDARG not %08x\n", hr);
+
+        hr = ScriptStringFree(&ssa);
+        /*
+         * ScriptStringCPtoX should free ssa, hence ScriptStringFree should fail
+         */
+        ok(hr == E_INVALIDARG, "ScriptStringFree should return E_INVALIDARG not %08x\n", hr);
+    }
+}
+
+static void test_ScriptCacheGetHeight(HDC hdc)
 {
     HRESULT hr;
     SCRIPT_CACHE sc = NULL;
@@ -698,7 +916,7 @@ void test_ScriptCacheGetHeight(HDC hdc)
     ok(height > 0, "expected height > 0\n");
 }
 
-void test_ScriptGetGlyphABCWidth(HDC hdc)
+static void test_ScriptGetGlyphABCWidth(HDC hdc)
 {
     HRESULT hr;
     LOGFONTA lf;
@@ -727,7 +945,7 @@ void test_ScriptGetGlyphABCWidth(HDC hdc)
     ok(hr == S_OK, "expected S_OK, got 0x%08x\n", hr);
 }
 
-void test_ScriptLayout(void)
+static void test_ScriptLayout(void)
 {
     HRESULT hr;
     static const BYTE levels[][5] =
@@ -1018,11 +1236,22 @@ static void test_digit_substitution(void)
         LGRPID_GEORGIAN,
         LGRPID_ARMENIAN
     };
+    HMODULE hKernel32;
+    static BOOL (WINAPI * pEnumLanguageGroupLocalesA)(LANGGROUPLOCALE_ENUMPROC,LGRPID,DWORD,LONG_PTR);
+
+    hKernel32 = GetModuleHandleA("kernel32.dll");
+    pEnumLanguageGroupLocalesA = (void*)GetProcAddress(hKernel32, "EnumLanguageGroupLocalesA");
+
+    if (!pEnumLanguageGroupLocalesA)
+    {
+        trace("EnumLanguageGroupLocalesA not available on this platform\n");
+        return;
+    }
 
     for (i = 0; i < sizeof(groups)/sizeof(groups[0]); i++)
     {
-        ret = EnumLanguageGroupLocales(enum_proc, groups[i], 0, 0);
-        ok(ret, "EnumLanguageGroupLocales failed unexpectedly: 0x%08x\n", GetLastError());
+        ret = pEnumLanguageGroupLocalesA(enum_proc, groups[i], 0, 0);
+        ok(ret, "EnumLanguageGroupLocalesA failed unexpectedly: 0x%08x\n", GetLastError());
     }
 }
 
@@ -1049,14 +1278,15 @@ START_TEST(usp10)
     test_ScriptCacheGetHeight(hdc);
     test_ScriptGetGlyphABCWidth(hdc);
 
-    ReleaseDC(hwnd, hdc);
-    DestroyWindow(hwnd);
-
     test_ScriptGetFontProperties();
     test_ScriptTextOut();
     test_ScriptXtoX();
     test_ScriptString();
-    test_ScriptLayout();
+    test_ScriptStringXtoCP_CPtoX(hdc);
 
+    test_ScriptLayout();
     test_digit_substitution();
+
+    ReleaseDC(hwnd, hdc);
+    DestroyWindow(hwnd);
 }
