@@ -70,6 +70,9 @@ static const UINT button_up_flags[NB_BUTTONS] =
 };
 
 POINT cursor_pos;
+static DWORD last_time_modified;
+
+BOOL X11DRV_SetCursorPos( INT x, INT y );
 
 /***********************************************************************
  *		get_coords
@@ -188,6 +191,7 @@ static void queue_raw_mouse_message( UINT message, HWND hwnd, DWORD x, DWORD y,
     hook.time        = time;
     hook.dwExtraInfo = extra_info;
 
+    last_time_modified = GetTickCount();
     if (HOOK_CallHooks( WH_MOUSE_LL, HC_ACTION, message, (LPARAM)&hook, TRUE )) return;
 
     SERVER_START_REQ( send_hardware_message )
@@ -216,7 +220,7 @@ void X11DRV_send_mouse_input( HWND hwnd, DWORD flags, DWORD x, DWORD y,
 {
     POINT pt;
 
-    if (flags & MOUSEEVENTF_ABSOLUTE)
+    if (flags & MOUSEEVENTF_MOVE && flags & MOUSEEVENTF_ABSOLUTE)
     {
         if (injected_flags & LLMHF_INJECTED)
         {
@@ -227,10 +231,10 @@ void X11DRV_send_mouse_input( HWND hwnd, DWORD flags, DWORD x, DWORD y,
         {
             pt.x = x;
             pt.y = y;
+            wine_tsx11_lock();
+            if (cursor_pos.x == x && cursor_pos.y == y) flags &= ~MOUSEEVENTF_MOVE;
+            wine_tsx11_unlock();
         }
-        wine_tsx11_lock();
-        cursor_pos = pt;
-        wine_tsx11_unlock();
     }
     else if (flags & MOUSEEVENTF_MOVE)
     {
@@ -259,7 +263,6 @@ void X11DRV_send_mouse_input( HWND hwnd, DWORD flags, DWORD x, DWORD y,
         else if (pt.x >= screen_width) pt.x = screen_width - 1;
         if (pt.y < 0) pt.y = 0;
         else if (pt.y >= screen_height) pt.y = screen_height - 1;
-        cursor_pos = pt;
         wine_tsx11_unlock();
     }
     else
@@ -276,10 +279,12 @@ void X11DRV_send_mouse_input( HWND hwnd, DWORD flags, DWORD x, DWORD y,
         if ((injected_flags & LLMHF_INJECTED) &&
             ((flags & MOUSEEVENTF_ABSOLUTE) || x || y))  /* we have to actually move the cursor */
         {
-            TRACE( "warping to (%d,%d)\n", pt.x, pt.y );
+            X11DRV_SetCursorPos( pt.x, pt.y );
+        }
+        else
+        {
             wine_tsx11_lock();
-            XWarpPointer( thread_display(), root_window, root_window, 0, 0, 0, 0,
-                          pt.x - virtual_screen_rect.left, pt.y - virtual_screen_rect.top );
+            cursor_pos = pt;
             wine_tsx11_unlock();
         }
     }
@@ -682,6 +687,14 @@ BOOL X11DRV_SetCursorPos( INT x, INT y )
     TRACE( "warping to (%d,%d)\n", x, y );
 
     wine_tsx11_lock();
+    if (cursor_pos.x == x && cursor_pos.y == y)
+    {
+        wine_tsx11_unlock();
+        /* We still need to generate WM_MOUSEMOVE */
+        queue_raw_mouse_message( WM_MOUSEMOVE, NULL, x, y, 0, GetCurrentTime(), 0, 0 );
+        return TRUE;
+    }
+
     XWarpPointer( display, root_window, root_window, 0, 0, 0, 0,
                   x - virtual_screen_rect.left, y - virtual_screen_rect.top );
     XFlush( display ); /* avoids bad mouse lag in games that do their own mouse warping */
@@ -702,7 +715,8 @@ BOOL X11DRV_GetCursorPos(LPPOINT pos)
     unsigned int xstate;
 
     wine_tsx11_lock();
-    if (XQueryPointer( display, root_window, &root, &child,
+    if ((GetTickCount() - last_time_modified > 100) &&
+        XQueryPointer( display, root_window, &root, &child,
                        &rootX, &rootY, &winX, &winY, &xstate ))
     {
         update_button_state( xstate );
@@ -748,7 +762,7 @@ void X11DRV_ButtonPress( HWND hwnd, XEvent *xev )
 
     update_mouse_state( hwnd, event->window, event->x, event->y, event->state, &pt );
 
-    X11DRV_send_mouse_input( hwnd, button_down_flags[buttonNum] | MOUSEEVENTF_ABSOLUTE,
+    X11DRV_send_mouse_input( hwnd, button_down_flags[buttonNum] | MOUSEEVENTF_ABSOLUTE | MOUSEEVENTF_MOVE,
                              pt.x, pt.y, wData, EVENT_x11_time_to_win32_time(event->time), 0, 0 );
 }
 
@@ -778,7 +792,7 @@ void X11DRV_ButtonRelease( HWND hwnd, XEvent *xev )
 
     update_mouse_state( hwnd, event->window, event->x, event->y, event->state, &pt );
 
-    X11DRV_send_mouse_input( hwnd, button_up_flags[buttonNum] | MOUSEEVENTF_ABSOLUTE,
+    X11DRV_send_mouse_input( hwnd, button_up_flags[buttonNum] | MOUSEEVENTF_ABSOLUTE | MOUSEEVENTF_MOVE,
                              pt.x, pt.y, wData, EVENT_x11_time_to_win32_time(event->time), 0, 0 );
 }
 
