@@ -70,8 +70,8 @@ static void check_position(int device, HWAVEIN win, DWORD bytes,
         trace("waveInGetPosition(%s): TIME_BYTES not supported, returned %s\n",
               dev_name(device),wave_time_format(mmtime.wType));
     returned = time_to_bytes(&mmtime, pwfx);
-    ok(returned == bytes, "waveInGetPosition(%s): returned %ld bytes, "
-       "should be %ld\n", dev_name(device), returned, bytes);
+    ok(returned == bytes, "waveInGetPosition(%s): returned %d bytes, "
+       "should be %d\n", dev_name(device), returned, bytes);
 
     mmtime.wType = TIME_SAMPLES;
     rc=waveInGetPosition(win, &mmtime, sizeof(mmtime));
@@ -81,8 +81,8 @@ static void check_position(int device, HWAVEIN win, DWORD bytes,
         trace("waveInGetPosition(%s): TIME_SAMPLES not supported, "
               "returned %s\n",dev_name(device),wave_time_format(mmtime.wType));
     returned = time_to_bytes(&mmtime, pwfx);
-    ok(returned == bytes, "waveInGetPosition(%s): returned %ld samples, "
-       "should be %ld\n", dev_name(device), bytes_to_samples(returned, pwfx),
+    ok(returned == bytes, "waveInGetPosition(%s): returned %d samples, "
+       "should be %d\n", dev_name(device), bytes_to_samples(returned, pwfx),
        bytes_to_samples(bytes, pwfx));
 
     mmtime.wType = TIME_MS;
@@ -93,8 +93,8 @@ static void check_position(int device, HWAVEIN win, DWORD bytes,
         trace("waveInGetPosition(%s): TIME_MS not supported, returned %s\n",
               dev_name(device), wave_time_format(mmtime.wType));
     returned = time_to_bytes(&mmtime, pwfx);
-    ok(returned == bytes, "waveInGetPosition(%s): returned %ld ms, "
-       "should be %ld\n", dev_name(device), bytes_to_ms(returned, pwfx),
+    ok(returned == bytes, "waveInGetPosition(%s): returned %d ms, "
+       "should be %d\n", dev_name(device), bytes_to_ms(returned, pwfx),
        bytes_to_ms(bytes, pwfx));
 
     mmtime.wType = TIME_SMPTE;
@@ -143,7 +143,7 @@ static void wave_in_test_deviceIn(int device, LPWAVEFORMATEX pwfx, DWORD format,
     DWORD nSamplesPerSec = pwfx->nSamplesPerSec;
 
     hevent=CreateEvent(NULL,FALSE,FALSE,NULL);
-    ok(hevent!=NULL,"CreateEvent(): error=%ld\n",GetLastError());
+    ok(hevent!=NULL,"CreateEvent(): error=%d\n",GetLastError());
     if (hevent==NULL)
         return;
 
@@ -159,7 +159,7 @@ static void wave_in_test_deviceIn(int device, LPWAVEFORMATEX pwfx, DWORD format,
        (!(flags & WAVE_FORMAT_DIRECT) || (flags & WAVE_MAPPED)) &&
        !(pcaps->dwFormats & format)) ||
        (rc==MMSYSERR_INVALFLAG && (flags & WAVE_FORMAT_DIRECT)),
-       "waveInOpen(%s): format=%ldx%2dx%d flags=%lx(%s) rc=%s\n",
+       "waveInOpen(%s): format=%dx%2dx%d flags=%lx(%s) rc=%s\n",
        dev_name(device),pwfx->nSamplesPerSec,pwfx->wBitsPerSample,
        pwfx->nChannels,CALLBACK_EVENT|flags,
        wave_open_flags(CALLBACK_EVENT|flags),wave_in_error(rc));
@@ -169,7 +169,7 @@ static void wave_in_test_deviceIn(int device, LPWAVEFORMATEX pwfx, DWORD format,
               "capabilities but opening it failed.\n");
     if ((rc==WAVERR_BADFORMAT || rc==MMSYSERR_NOTSUPPORTED) &&
        !(pcaps->dwFormats & format))
-        trace("waveInOpen(%s): format=%ldx%2dx%d %s rc=%s failed but format "
+        trace("waveInOpen(%s): format=%dx%2dx%d %s rc=%s failed but format "
               "not supported so OK.\n",dev_name(device),pwfx->nSamplesPerSec,
               pwfx->wBitsPerSample,pwfx->nChannels,
               flags & WAVE_FORMAT_DIRECT ? "flags=WAVE_FORMAT_DIRECT" :
@@ -184,7 +184,7 @@ static void wave_in_test_deviceIn(int device, LPWAVEFORMATEX pwfx, DWORD format,
     ok(pwfx->nChannels==nChannels &&
        pwfx->wBitsPerSample==wBitsPerSample &&
        pwfx->nSamplesPerSec==nSamplesPerSec,
-       "got the wrong format: %ldx%2dx%d instead of %ldx%2dx%d\n",
+       "got the wrong format: %dx%2dx%d instead of %dx%2dx%d\n",
        pwfx->nSamplesPerSec, pwfx->wBitsPerSample,
        pwfx->nChannels, nSamplesPerSec, wBitsPerSample, nChannels);
 
@@ -206,7 +206,7 @@ static void wave_in_test_deviceIn(int device, LPWAVEFORMATEX pwfx, DWORD format,
        "not set\n",dev_name(device));
 
     if (winetest_interactive && rc==MMSYSERR_NOERROR) {
-        trace("Recording for 1 second at %5ldx%2dx%d %s %s\n",
+        trace("Recording for 1 second at %5dx%2dx%d %s %s\n",
               pwfx->nSamplesPerSec, pwfx->wBitsPerSample,pwfx->nChannels,
               get_format_str(pwfx->wFormatTag),
               flags & WAVE_FORMAT_DIRECT ? "WAVE_FORMAT_DIRECT" :
@@ -226,7 +226,7 @@ static void wave_in_test_deviceIn(int device, LPWAVEFORMATEX pwfx, DWORD format,
         ok(res==WAIT_OBJECT_0,"WaitForSingleObject failed for header\n");
         ok(frag.dwFlags&WHDR_DONE,"WHDR_DONE not set in frag.dwFlags\n");
         ok(frag.dwBytesRecorded==pwfx->nAvgBytesPerSec,
-           "frag.dwBytesRecorded=%ld, should=%ld\n",
+           "frag.dwBytesRecorded=%d, should=%d\n",
            frag.dwBytesRecorded,pwfx->nAvgBytesPerSec);
 
         /* stop playing on error */
@@ -261,7 +261,7 @@ static void wave_in_test_deviceIn(int device, LPWAVEFORMATEX pwfx, DWORD format,
            rc==MMSYSERR_ALLOCATED ||
            ((rc==WAVERR_BADFORMAT || rc==MMSYSERR_NOTSUPPORTED) &&
             !(pcaps->dwFormats & format)),
-           "waveOutOpen(%s) format=%ldx%2dx%d flags=%lx(%s) rc=%s\n",
+           "waveOutOpen(%s) format=%dx%2dx%d flags=%lx(%s) rc=%s\n",
            dev_name(device),pwfx->nSamplesPerSec,pwfx->wBitsPerSample,
            pwfx->nChannels,CALLBACK_EVENT|flags,
            wave_open_flags(CALLBACK_EVENT),wave_out_error(rc));
@@ -375,7 +375,7 @@ static void wave_in_test_device(int device)
         ok(rc==MMSYSERR_NOERROR,"waveInMessage(%s): failed to get interface "
            "name: rc=%s\n",dev_name(device),wave_in_error(rc));
         ok(lstrlenW(nameW)+1==size/sizeof(WCHAR),
-           "got an incorrect size %ld\n", size);
+           "got an incorrect size %d\n", size);
         if (rc==MMSYSERR_NOERROR) {
             nameA = malloc(size/sizeof(WCHAR));
             WideCharToMultiByte(CP_ACP, 0, nameW, size/sizeof(WCHAR),
@@ -389,7 +389,7 @@ static void wave_in_test_device(int device)
     trace("  %s: \"%s\" (%s) %d.%d (%d:%d)\n",dev_name(device),capsA.szPname,
           (nameA?nameA:"failed"),capsA.vDriverVersion >> 8,
           capsA.vDriverVersion & 0xff,capsA.wMid,capsA.wPid);
-    trace("     channels=%d formats=%05lx\n",
+    trace("     channels=%d formats=%05x\n",
           capsA.wChannels,capsA.dwFormats);
 
     free(nameA);
@@ -455,7 +455,7 @@ static void wave_in_test_device(int device)
        "waveInOpen(%s): opening the device with 2 MHz sample rate should fail: "
        " rc=%s\n",dev_name(device),wave_in_error(rc));
     if (rc==MMSYSERR_NOERROR) {
-        trace("     got %ldx%2dx%d for %ldx%2dx%d\n",
+        trace("     got %dx%2dx%d for %dx%2dx%d\n",
               format.nSamplesPerSec, format.wBitsPerSample,
               format.nChannels,
               oformat.nSamplesPerSec, oformat.wBitsPerSample,
