@@ -76,7 +76,7 @@ BOOL dbg_attach_debuggee(DWORD pid, BOOL cofe)
 
     if (!DebugActiveProcess(pid)) 
     {
-        dbg_printf("Can't attach process %lx: error %ld\n", pid, GetLastError());
+        dbg_printf("Can't attach process %04x: error %u\n", pid, GetLastError());
         dbg_del_process(dbg_curr_process);
 	return FALSE;
     }
@@ -203,7 +203,7 @@ static unsigned dbg_exception_prolog(BOOL is_debug, const EXCEPTION_RECORD* rec)
                 HeapFree(GetProcessHeap(), 0, last_file);
                 last_name = strcpy(HeapAlloc(GetProcessHeap(), 0, strlen(si->Name) + 1), si->Name);
                 last_file = strcpy(HeapAlloc(GetProcessHeap(), 0, strlen(il.FileName) + 1), il.FileName);
-                dbg_printf("%s () at %s:%ld\n", last_name, last_file, il.LineNumber);
+                dbg_printf("%s () at %s:%u\n", last_name, last_file, il.LineNumber);
             }
         }
     }
@@ -241,7 +241,7 @@ static DWORD dbg_handle_exception(const EXCEPTION_RECORD* rec, BOOL first_chance
 
     assert(dbg_curr_thread);
 
-    WINE_TRACE("exception=%lx first_chance=%c\n",
+    WINE_TRACE("exception=%x first_chance=%c\n",
                rec->ExceptionCode, first_chance ? 'Y' : 'N');
 
     switch (rec->ExceptionCode)
@@ -258,11 +258,11 @@ static DWORD dbg_handle_exception(const EXCEPTION_RECORD* rec, BOOL first_chance
             pThread = dbg_get_thread(dbg_curr_process, pThreadName->dwThreadID);
         if(!pThread)
         {
-            dbg_printf("Thread ID=0x%lx not in our list of threads -> can't rename\n", pThreadName->dwThreadID);
+            dbg_printf("Thread ID=%04x not in our list of threads -> can't rename\n", pThreadName->dwThreadID);
             return DBG_CONTINUE;
         }
         if (dbg_read_memory(pThreadName->szName, pThread->name, 9))
-            dbg_printf("Thread ID=0x%lx renamed using MS VC6 extension (name==\"%s\")\n",
+            dbg_printf("Thread ID=%04x renamed using MS VC6 extension (name==\"%s\")\n",
                        pThread->tid, pThread->name);
         return DBG_CONTINUE;
     }
@@ -382,7 +382,7 @@ static DWORD dbg_handle_exception(const EXCEPTION_RECORD* rec, BOOL first_chance
             dbg_printf("floating point stack check");
             break;
         default:
-            dbg_printf("0x%08lx", rec->ExceptionCode);
+            dbg_printf("0x%08x", rec->ExceptionCode);
             break;
         }
     }
@@ -423,7 +423,7 @@ static void fetch_module_name(void* name_addr, BOOL unicode, void* mod_addr,
             if (!(h = GetModuleHandleA("psapi")) ||
                 !(gpif = (void*)GetProcAddress(h, "GetProcessImageFileName")) ||
                 !(gpif)(dbg_curr_process->handle, buffer, bufsz))
-                snprintf(buffer, bufsz, "Process_%08lx", dbg_curr_pid);
+                snprintf(buffer, bufsz, "Process_%08x", dbg_curr_pid);
         }
         else
             snprintf(buffer, bufsz, "DLL_%p", mod_addr);
@@ -448,12 +448,12 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
     case EXCEPTION_DEBUG_EVENT:
         if (!dbg_curr_thread)
         {
-            WINE_ERR("%08lx:%08lx: not a registered process or thread (perhaps a 16 bit one ?)\n",
+            WINE_ERR("%04x:%04x: not a registered process or thread (perhaps a 16 bit one ?)\n",
                      de->dwProcessId, de->dwThreadId);
             break;
         }
 
-        WINE_TRACE("%08lx:%08lx: exception code=%08lx\n",
+        WINE_TRACE("%04x:%04x: exception code=%08x\n",
                    de->dwProcessId, de->dwThreadId,
                    de->u.Exception.ExceptionRecord.ExceptionCode);
 
@@ -486,10 +486,10 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
                           de->u.CreateProcessInfo.lpBaseOfImage,
                           buffer, sizeof(buffer), TRUE);
 
-        WINE_TRACE("%08lx:%08lx: create process '%s'/%p @%08lx (%ld<%ld>)\n",
+        WINE_TRACE("%04x:%04x: create process '%s'/%p @%p (%u<%u>)\n",
                    de->dwProcessId, de->dwThreadId,
                    buffer, de->u.CreateProcessInfo.lpImageName,
-                   (unsigned long)(void*)de->u.CreateProcessInfo.lpStartAddress,
+                   de->u.CreateProcessInfo.lpStartAddress,
                    de->u.CreateProcessInfo.dwDebugInfoFileOffset,
                    de->u.CreateProcessInfo.nDebugInfoSize);
         dbg_set_process_name(dbg_curr_process, buffer);
@@ -498,11 +498,10 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
             dbg_printf("Couldn't initiate DbgHelp\n");
         if (!SymLoadModule(dbg_curr_process->handle, de->u.CreateProcessInfo.hFile, buffer, NULL,
                            (unsigned long)de->u.CreateProcessInfo.lpBaseOfImage, 0))
-            dbg_printf("couldn't load main module (%lx)\n", GetLastError());
+            dbg_printf("couldn't load main module (%u)\n", GetLastError());
 
-        WINE_TRACE("%08lx:%08lx: create thread I @%08lx\n",
-                   de->dwProcessId, de->dwThreadId,
-                   (unsigned long)(void*)de->u.CreateProcessInfo.lpStartAddress);
+        WINE_TRACE("%04x:%04x: create thread I @%p\n",
+                   de->dwProcessId, de->dwThreadId, de->u.CreateProcessInfo.lpStartAddress);
 
         dbg_curr_thread = dbg_add_thread(dbg_curr_process,
                                          de->dwThreadId,
@@ -518,7 +517,7 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
         break;
 
     case EXIT_PROCESS_DEBUG_EVENT:
-        WINE_TRACE("%08lx:%08lx: exit process (%ld)\n",
+        WINE_TRACE("%04x:%04x: exit process (%d)\n",
                    de->dwProcessId, de->dwThreadId, de->u.ExitProcess.dwExitCode);
 
         if (dbg_curr_process == NULL)
@@ -527,13 +526,12 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
             break;
         }
         tgt_process_active_close_process(dbg_curr_process, FALSE);
-        dbg_printf("Process of pid=0x%08lx has terminated\n", de->dwProcessId);
+        dbg_printf("Process of pid=%04x has terminated\n", de->dwProcessId);
         break;
 
     case CREATE_THREAD_DEBUG_EVENT:
-        WINE_TRACE("%08lx:%08lx: create thread D @%08lx\n",
-                   de->dwProcessId, de->dwThreadId,
-                   (unsigned long)(void*)de->u.CreateThread.lpStartAddress);
+        WINE_TRACE("%04x:%04x: create thread D @%p\n",
+                   de->dwProcessId, de->dwThreadId, de->u.CreateThread.lpStartAddress);
 
         if (dbg_curr_process == NULL)
         {
@@ -559,7 +557,7 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
         break;
 
     case EXIT_THREAD_DEBUG_EVENT:
-        WINE_TRACE("%08lx:%08lx: exit thread (%ld)\n",
+        WINE_TRACE("%04x:%04x: exit thread (%d)\n",
                    de->dwProcessId, de->dwThreadId, de->u.ExitThread.dwExitCode);
 
         if (dbg_curr_thread == NULL)
@@ -582,9 +580,9 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
                           de->u.LoadDll.lpBaseOfDll,
                           buffer, sizeof(buffer), FALSE);
 
-        WINE_TRACE("%08lx:%08lx: loads DLL %s @%08lx (%ld<%ld>)\n",
+        WINE_TRACE("%04x:%04x: loads DLL %s @%p (%u<%u>)\n",
                    de->dwProcessId, de->dwThreadId,
-                   buffer, (unsigned long)de->u.LoadDll.lpBaseOfDll,
+                   buffer, de->u.LoadDll.lpBaseOfDll,
                    de->u.LoadDll.dwDebugInfoFileOffset,
                    de->u.LoadDll.nDebugInfoSize);
         SymLoadModule(dbg_curr_process->handle, de->u.LoadDll.hFile, buffer, NULL,
@@ -601,9 +599,9 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
         break;
 
     case UNLOAD_DLL_DEBUG_EVENT:
-        WINE_TRACE("%08lx:%08lx: unload DLL @%08lx\n", 
+        WINE_TRACE("%04x:%04x: unload DLL @%p\n",
                    de->dwProcessId, de->dwThreadId,
-                   (unsigned long)de->u.UnloadDll.lpBaseOfDll);
+                   de->u.UnloadDll.lpBaseOfDll);
         break_delete_xpoints_from_module((unsigned long)de->u.UnloadDll.lpBaseOfDll);
         SymUnloadModule(dbg_curr_process->handle, 
                         (unsigned long)de->u.UnloadDll.lpBaseOfDll);
@@ -619,18 +617,18 @@ static unsigned dbg_handle_debug_event(DEBUG_EVENT* de)
         memory_get_string(dbg_curr_process,
                           de->u.DebugString.lpDebugStringData, TRUE,
                           de->u.DebugString.fUnicode, buffer, sizeof(buffer));
-        WINE_TRACE("%08lx:%08lx: output debug string (%s)\n",
+        WINE_TRACE("%04x:%04x: output debug string (%s)\n",
                    de->dwProcessId, de->dwThreadId, buffer);
         break;
 
     case RIP_EVENT:
-        WINE_TRACE("%08lx:%08lx: rip error=%ld type=%ld\n",
+        WINE_TRACE("%04x:%04x: rip error=%u type=%u\n",
                    de->dwProcessId, de->dwThreadId, de->u.RipInfo.dwError,
                    de->u.RipInfo.dwType);
         break;
 
     default:
-        WINE_TRACE("%08lx:%08lx: unknown event (%ld)\n",
+        WINE_TRACE("%04x:%04x: unknown event (%x)\n",
                    de->dwProcessId, de->dwThreadId, de->dwDebugEventCode);
     }
     if (!cont) return TRUE;  /* stop execution */
@@ -654,12 +652,12 @@ static void dbg_resume_debuggee(DWORD cont)
         if (dbg_curr_thread)
         {
             if (!SetThreadContext(dbg_curr_thread->handle, &dbg_context))
-                dbg_printf("Cannot set ctx on %lu\n", dbg_curr_tid);
+                dbg_printf("Cannot set ctx on %04x\n", dbg_curr_tid);
         }
     }
     dbg_interactiveP = FALSE;
     if (!ContinueDebugEvent(dbg_curr_pid, dbg_curr_tid, cont))
-        dbg_printf("Cannot continue on %lu (%lu)\n", dbg_curr_tid, cont);
+        dbg_printf("Cannot continue on %04x (%08x)\n", dbg_curr_tid, cont);
 }
 
 static void wait_exception(void)
@@ -805,7 +803,7 @@ enum dbg_start  dbg_active_attach(int argc, char* argv[])
         }
         if (!SetEvent((HANDLE)evt))
         {
-            WINE_ERR("Invalid event handle: %lx\n", evt);
+            WINE_ERR("Invalid event handle: %x\n", evt);
             return start_error_init;
         }
         CloseHandle((HANDLE)evt);
