@@ -165,10 +165,7 @@ static void remove_dir (const char *dir)
 static const char* get_test_source_file(const char* test, const char* subtest)
 {
     static const char* special_dirs[][2] = {
-	{ "gdi32", "gdi"}, { "kernel32", "kernel" },
-        { "msacm32", "msacm" },
-	{ "user32", "user" }, { "winspool.drv", "winspool" },
-	{ "ws2_32", "winsock" }, { 0, 0 }
+	{ 0, 0 }
     };
     static char buffer[MAX_PATH];
     int i;
@@ -277,8 +274,7 @@ run_ex (char *cmd, const char *out, DWORD ms)
     DWORD wait, status;
 
     GetStartupInfo (&si);
-    si.wShowWindow = SW_HIDE;
-    si.dwFlags = STARTF_USESHOWWINDOW;
+    si.dwFlags = 0;
 
     if (out) {
         fd = open (out, O_WRONLY | O_CREAT, 0666);
