@@ -134,7 +134,7 @@ static void pipe_server_dump( struct object *obj, int verbose );
 static struct fd *pipe_server_get_fd( struct object *obj );
 static void pipe_server_destroy( struct object *obj);
 static int pipe_server_flush( struct fd *fd, struct event **event );
-static int pipe_server_get_info( struct fd *fd );
+static enum server_fd_type pipe_server_get_info( struct fd *fd, int *flags );
 
 static const struct object_ops pipe_server_ops =
 {
@@ -148,7 +148,7 @@ static const struct object_ops pipe_server_ops =
     pipe_server_get_fd,           /* get_fd */
     pipe_map_access,              /* map_access */
     no_lookup_name,               /* lookup_name */
-    no_close_handle,              /* close_handle */
+    fd_close_handle,              /* close_handle */
     pipe_server_destroy           /* destroy */
 };
 
@@ -167,7 +167,7 @@ static void pipe_client_dump( struct object *obj, int verbose );
 static struct fd *pipe_client_get_fd( struct object *obj );
 static void pipe_client_destroy( struct object *obj );
 static int pipe_client_flush( struct fd *fd, struct event **event );
-static int pipe_client_get_info( struct fd *fd );
+static enum server_fd_type pipe_client_get_info( struct fd *fd, int *flags );
 
 static const struct object_ops pipe_client_ops =
 {
@@ -181,7 +181,7 @@ static const struct object_ops pipe_client_ops =
     pipe_client_get_fd,           /* get_fd */
     pipe_map_access,              /* map_access */
     no_lookup_name,               /* lookup_name */
-    no_close_handle,              /* close_handle */
+    fd_close_handle,              /* close_handle */
     pipe_client_destroy           /* destroy */
 };
 
@@ -200,7 +200,7 @@ static struct fd *named_pipe_device_get_fd( struct object *obj );
 static struct object *named_pipe_device_lookup_name( struct object *obj,
     struct unicode_str *name, unsigned int attr );
 static void named_pipe_device_destroy( struct object *obj );
-static int named_pipe_device_get_file_info( struct fd *fd );
+static enum server_fd_type named_pipe_device_get_file_info( struct fd *fd, int *flags );
 
 static const struct object_ops named_pipe_device_ops =
 {
@@ -214,7 +214,7 @@ static const struct object_ops named_pipe_device_ops =
     named_pipe_device_get_fd,         /* get_fd */
     pipe_map_access,                  /* map_access */
     named_pipe_device_lookup_name,    /* lookup_name */
-    no_close_handle,                  /* close_handle */
+    fd_close_handle,                  /* close_handle */
     named_pipe_device_destroy         /* destroy */
 };
 
@@ -438,9 +438,10 @@ static void named_pipe_device_destroy( struct object *obj )
     free( device->pipes );
 }
 
-static int named_pipe_device_get_file_info( struct fd *fd )
+static enum server_fd_type named_pipe_device_get_file_info( struct fd *fd, int *flags )
 {
-    return 0;
+    *flags = 0;
+    return FD_TYPE_DEVICE;
 }
 
 void create_named_pipe_device( struct directory *root, const struct unicode_str *name )
@@ -545,24 +546,22 @@ static inline int is_overlapped( unsigned int options )
     return !(options & (FILE_SYNCHRONOUS_IO_ALERT | FILE_SYNCHRONOUS_IO_NONALERT));
 }
 
-static int pipe_server_get_info( struct fd *fd )
+static enum server_fd_type pipe_server_get_info( struct fd *fd, int *flags )
 {
     struct pipe_server *server = get_fd_user( fd );
-    int flags = FD_FLAG_AVAILABLE;
- 
-    if (is_overlapped( server->options )) flags |= FD_FLAG_OVERLAPPED;
 
-    return flags;
+    *flags = FD_FLAG_AVAILABLE;
+    if (is_overlapped( server->options )) *flags |= FD_FLAG_OVERLAPPED;
+    return FD_TYPE_PIPE;
 }
 
-static int pipe_client_get_info( struct fd *fd )
+static enum server_fd_type pipe_client_get_info( struct fd *fd, int *flags )
 {
     struct pipe_client *client = get_fd_user( fd );
-    int flags = FD_FLAG_AVAILABLE;
 
-    if (is_overlapped( client->flags )) flags |= FD_FLAG_OVERLAPPED;
-
-    return flags;
+    *flags = FD_FLAG_AVAILABLE;
+    if (is_overlapped( client->flags )) *flags |= FD_FLAG_OVERLAPPED;
+    return FD_TYPE_PIPE;
 }
 
 static struct named_pipe *create_named_pipe( struct directory *root, const struct unicode_str *name,
@@ -884,7 +883,6 @@ DECL_HANDLER(disconnect_named_pipe)
 {
     struct pipe_server *server;
 
-    reply->fd = -1;
     server = get_pipe_server_obj( current->process, req->handle, 0 );
     if (!server)
         return;
@@ -901,7 +899,6 @@ DECL_HANDLER(disconnect_named_pipe)
            around - client loses all waiting data */
         server->state = ps_disconnected_server;
         do_disconnect( server );
-        reply->fd = flush_cached_fd( current->process, req->handle );
         break;
 
     case ps_wait_disconnect:
@@ -909,7 +906,6 @@ DECL_HANDLER(disconnect_named_pipe)
         assert( server->fd );
         do_disconnect( server );
         server->state = ps_wait_connect;
-        reply->fd = flush_cached_fd( current->process, req->handle );
         break;
 
     case ps_idle_server:
