@@ -515,7 +515,7 @@ static ACL *create_default_dacl( const SID *user )
     memcpy( sid, &local_system_sid, sizeof(local_system_sid) );
 
     /* GENERIC_ALL for specified user */
-    aaa = (ACCESS_ALLOWED_ACE *)((const char *)aaa + aaa->Header.AceSize);
+    aaa = (ACCESS_ALLOWED_ACE *)((char *)aaa + aaa->Header.AceSize);
     aaa->Header.AceType = ACCESS_ALLOWED_ACE_TYPE;
     aaa->Header.AceFlags = 0;
     aaa->Header.AceSize = (sizeof(ACCESS_ALLOWED_ACE) - sizeof(DWORD)) +
@@ -594,12 +594,9 @@ struct token *token_create_admin( void )
                             default_dacl, admin_source );
     }
 
-    if (alias_admins_sid)
-        free( alias_admins_sid );
-    if (alias_users_sid)
-        free( alias_users_sid );
-    if (default_dacl)
-        free( default_dacl );
+    free( alias_admins_sid );
+    free( alias_users_sid );
+    free( default_dacl );
 
     return token;
 }
