@@ -47,6 +47,11 @@
 #include <assert.h>
 #include <stdarg.h>
 
+#define NONAMELESSUNION
+#define NONAMELESSSTRUCT
+#include "windef.h"
+#include "winbase.h"
+
 /* Argument type constants */
 #define MAX_FUNCTION_ARGS   32
 
@@ -72,7 +77,7 @@
 #define SYM_THISCALL        0x4
 #define SYM_DATA            0x8 /* Data, not a function */
 
-typedef enum {NONE, DMGL, SPEC, DUMP, EMF, LNK} Mode;
+typedef enum {NONE, DMGL, SPEC, DUMP} Mode;
 
 /* Structure holding a parsed symbol */
 typedef struct __parsed_symbol
@@ -123,6 +128,8 @@ typedef struct __globals
   /* Options: dump mode */
   int   do_demangle;        /* -d */
   int   do_dumpheader;      /* -f */
+  int   do_dump_rawdata;    /* -x */
+  int   do_debug;           /* -G == 1, -g == 2 */
 
   /* Option arguments: spec mode */
   int   start_ordinal;     /* -s */
@@ -155,12 +162,6 @@ extern _globals globals;
 /* Default calling convention */
 #define CALLING_CONVENTION (globals.do_cdecl ? SYM_CDECL : SYM_STDCALL)
 
-/* EMF functions */
-int   dump_emf (const char *emf);
-
-/* LNK functions */
-int   dump_lnk (const char *lnk);
-
 /* Image functions */
 void	dump_file(const char* name);
 
@@ -205,8 +206,6 @@ void  output_prototype (FILE *file, const parsed_symbol *sym);
 
 void  output_makefile (void);
 
-void  output_install_script (void);
-
 /* Misc functions */
 char *str_create (size_t num_str, ...);
 
@@ -222,23 +221,48 @@ const char *str_find_set (const char *str, const char *findset);
 
 char *str_toupper (char *str);
 
+const char *get_machine_str(int mach);
+
 /* file dumping functions */
-enum FileSig {SIG_UNKNOWN, SIG_DOS, SIG_PE, SIG_DBG, SIG_NE, SIG_LE, SIG_MDMP};
+enum FileSig {SIG_UNKNOWN, SIG_DOS, SIG_PE, SIG_DBG, SIG_PDB, SIG_NE, SIG_LE, SIG_MDMP, SIG_COFFLIB, SIG_LNK, SIG_EMF};
 
 const void*	PRD(unsigned long prd, unsigned long len);
 unsigned long	Offset(const void* ptr);
 
-typedef void (*file_dumper)(enum FileSig, const void*);
+typedef void (*file_dumper)(void);
 int             dump_analysis(const char*, file_dumper, enum FileSig);
 
 void            dump_data( const unsigned char *ptr, unsigned int size, const char *prefix );
 const char*	get_time_str( unsigned long );
 unsigned int    strlenW( const unsigned short *str );
 void            dump_unicode_str( const unsigned short *str, int len );
+void            dump_file_header(const IMAGE_FILE_HEADER *);
+void            dump_optional_header(const IMAGE_OPTIONAL_HEADER32 *, UINT);
+void            dump_section(const IMAGE_SECTION_HEADER *);
 
-void            ne_dump( const void *exe, size_t exe_size );
-void            le_dump( const void *exe, size_t exe_size );
+enum FileSig    get_kind_exec(void);
+void            pe_dump( void );
+void            ne_dump( void );
+void            le_dump( void );
+enum FileSig    get_kind_mdmp(void);
 void            mdmp_dump( void );
+enum FileSig    get_kind_lib(void);
+void            lib_dump( void );
+enum FileSig    get_kind_dbg(void);
+void	        dbg_dump( void );
+enum FileSig    get_kind_lnk(void);
+void	        lnk_dump( void );
+enum FileSig    get_kind_emf(void);
+void            emf_dump( void );
+enum FileSig    get_kind_pdb(void);
+void            pdb_dump(void);
+int             codeview_dump_symbols(const void* root, unsigned long size);
+int             codeview_dump_types(const void* table, unsigned long len);
+
+void            dump_stabs(const void* pv_stabs, unsigned szstabs, const char* stabstr, unsigned szstr);
+void		dump_codeview(unsigned long ptr, unsigned long len);
+void		dump_coff(unsigned long coffbase, unsigned long len, const void* sect_map);
+void		dump_frame_pointer_omission(unsigned long base, unsigned long len);
 
 FILE *open_file (const char *name, const char *ext, const char *mode);
 
